package ext {
import ext.window.MessageBoxWindow;

[Uses("ext.window.MessageBoxWindow")]
[Uses("ext.window.Window")]
[Uses("ext.panel.Panel")]
[Uses("ext.container.DockingContainer")]
[Uses("ext.Base")]
[Uses("ext.container.Container")]
[Uses("ext.mixin.Queryable")]
[Uses("ext.Component")]
[Uses("ext.util.Animate")]
[Uses("ext.util.ElementContainer")]
[Uses("ext.util.Focusable")]
[Uses("ext.mixin.ComponentDelegation")]
[Uses("ext.Mixin")]
[Uses("ext.mixin.Inheritable")]
[Uses("ext.util.Positionable")]
[Uses("ext.mixin.Bindable")]
[Uses("ext.mixin.Keyboard")]
[Uses("ext.mixin.Observable")]
[Uses("ext.mixin.Identifiable")]
[Uses("ext.state.Stateful")]
[Uses("ext.mixin.Accessible")]
[Uses("ext.util.Renderable")]
[Uses("ext.util.Floating")]
[Uses("ext.mixin.Container")]
[Native("Ext.MessageBox", require = "Ext.window.MessageBox")]
/**
 * Utility class for generating different styles of message boxes. The singleton instance, Ext.MessageBox
 * alias <code>ext.SMessageBox</code> can also be used.
 * <p>Note that a MessageBox is asynchronous. Unlike a regular JavaScript <code>alert</code> (which will halt
 * browser execution), showing a MessageBox will not cause the code to stop. For this reason, if you have code
 * that should only run <i>after</i> some user feedback from the MessageBox, you must use a callback function
 * (see the <code>function</code> parameter for <code>show()</code> for more details).</p>
 * <p>Basic alert</p>
 * <p><b>Example:</b></p>
 * <pre>
 * Ext.Msg.alert('Status', 'Changes saved successfully.');
 * </pre>
 * <p>Prompt for user data and process the result using a callback</p>
 * <p><b>Example:</b></p>
 * <pre>
 * Ext.Msg.prompt('Name', 'Please enter your name:', function(btn, text){
 *     if (btn == 'ok'){
 *         // process text value and close...
 *     }
 * });
 * </pre>
 * <p>Show a dialog using config options</p>
 * <p><b>Example:</b></p>
 * <pre>
 * Ext.Msg.show({
 *     title:'Save Changes?',
 *     message: 'You are closing a tab that has unsaved changes. Would you like to save your changes?',
 *     buttons: Ext.Msg.YESNOCANCEL,
 *     icon: Ext.Msg.QUESTION,
 *     fn: function(btn) {
 *         if (btn === 'yes') {
 *             console.log('Yes pressed');
 *         } else if (btn === 'no') {
 *             console.log('No pressed');
 *         } else {
 *             console.log('Cancel pressed');
 *         }
 *     }
 * });
 * </pre>
 * <p>Showing Ext.Msg while it's already shown will cause the visible instance to be
 * overwritten with the newly passed config. While this may be the desired outcome, you
 * can also create a new MessageBox that can exist alongside the Ext.Msg
 * singleton instance.</p>
 * <p><b>Example:</b></p>
 * <pre>
 * var myMsg = Ext.create('Ext.window.MessageBox', {
 *     // set closeAction to 'destroy' if this instance is not
 *     // intended to be reused by the application
 *     closeAction: 'destroy'
 * }).show({
 *     title: 'Custom MessageBox Instance',
 *     message: 'I can exist along with Ext.Msg'
 * });
 *
 * Ext.Msg.alert('Overlapping', 'Ext.Msg instance');
 * </pre>
 * @see ext.SMessageBox
 * @see SMessageBox#alert()
 * @see SMessageBox#show()
 * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.MessageBox.html Original Ext JS documentation of 'Ext.MessageBox'
 */
public const MessageBox:ext.window.MessageBoxWindow;
}