package ext {
import ext.app.ViewController;
import ext.app.ViewModel;
import ext.container.Container;
import ext.data.Session;
import ext.mixin.IBindable;
import ext.mixin.IComponentDelegation;
import ext.mixin.IInheritable;
import ext.mixin.IPluggable;
import ext.mixin.Observable;
import ext.plugin.AbstractPlugin;

[Uses("ext.Evented")]
[Uses("ext.mixin.Inheritable")]
[Uses("ext.mixin.Bindable")]
[Uses("ext.mixin.ComponentDelegation")]
[Uses("ext.mixin.Pluggable")]
[Uses("ext.Mixin")]
[Uses("ext.Base")]
[Uses("ext.mixin.Observable")]
[Uses("ext.mixin.Identifiable")]
[Native("Ext.Widget", require)]
/**
 * @see ext.events.Widget_value_oldValueEvent.BEFORE_HEIGHT_CHANGE
 * @eventType ext.events.Widget_value_oldValueEvent.BEFORE_HEIGHT_CHANGE
 */
[Event(name = 'onBeforeHeightChange', type = 'ext.events.Widget_value_oldValueEvent')]
/**
 * @see ext.events.Widget_value_oldValueEvent.HEIGHT_CHANGE
 * @eventType ext.events.Widget_value_oldValueEvent.HEIGHT_CHANGE
 */
[Event(name = 'onHeightChange', type = 'ext.events.Widget_value_oldValueEvent')]
/**
 * @see ext.events.Widget_value_oldValueEvent.BEFORE_HIDDEN_CHANGE
 * @eventType ext.events.Widget_value_oldValueEvent.BEFORE_HIDDEN_CHANGE
 */
[Event(name = 'onBeforeHiddenChange', type = 'ext.events.Widget_value_oldValueEvent')]
/**
 * @see ext.events.Widget_value_oldValueEvent.HIDDEN_CHANGE
 * @eventType ext.events.Widget_value_oldValueEvent.HIDDEN_CHANGE
 */
[Event(name = 'onHiddenChange', type = 'ext.events.Widget_value_oldValueEvent')]
/**
 * @see ext.events.Widget_value_oldValueEvent.BEFORE_WIDTH_CHANGE
 * @eventType ext.events.Widget_value_oldValueEvent.BEFORE_WIDTH_CHANGE
 */
[Event(name = 'onBeforeWidthChange', type = 'ext.events.Widget_value_oldValueEvent')]
/**
 * @see ext.events.Widget_value_oldValueEvent.WIDTH_CHANGE
 * @eventType ext.events.Widget_value_oldValueEvent.WIDTH_CHANGE
 */
[Event(name = 'onWidthChange', type = 'ext.events.Widget_value_oldValueEvent')]
/**
 * Ext.Widget is a light-weight Component that consists of nothing more than a template
 * Element that can be cloned to quickly and efficiently replicate many instances.
 * Ext.Widget is typically not instantiated directly, because the default template is
 * just a single element with no listeners. Instead Ext.Widget should be extended to
 * create Widgets that have a useful markup structure and event listeners.
 * <p>For example:</p>
 * <pre>
 *  Ext.define('MyWidget', {
 *      extend: 'Ext.Widget',
 *
 *      // The element template passed to Ext.Element.create()
 *      element: {
 *          reference: 'element',
 *          listeners: {
 *              click: 'onClick'
 *          },
 *          children: [{
 *              reference: 'innerElement',
 *              listeners: {
 *                  click: 'onInnerClick'
 *              }
 *          }]
 *      },
 *
 *      constructor: function(config) {
 *          // It is important to remember to call the Widget superclass constructor
 *          // when overriding the constructor in a derived class. This ensures that
 *          // the element is initialized from the template, and that initConfig() is
 *          // is called.
 *          this.callParent([config]);
 *
 *          // After calling the superclass constructor, the Element is available and
 *          // can safely be manipulated. Reference Elements are instances of
 *          // Ext.Element, and are cached on each Widget instance by reference name.
 *          Ext.getBody().appendChild(this.element);
 *      },
 *
 *      onClick: function() {
 *          // listeners use this Widget instance as their scope
 *          console.log('element clicked', this);
 *      },
 *
 *      onInnerClick: function() {
 *          // access the innerElement reference by name
 *          console.log('inner element clicked', this.innerElement);
 *      }
 *  });
 * </pre>
 * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Widget.html Original Ext JS documentation of 'Ext.Widget'
 */
public class Widget extends ext.Evented implements ext.mixin.IInheritable, ext.mixin.IBindable, ext.mixin.IComponentDelegation, ext.mixin.IPluggable {
  /**
   * @param config @inheritDoc
   */
  public function Widget(config:ext.Widget = null) {
    super();
  }

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * The base CSS class to apply to this widget's element.
   * Used as the prefix for <code>ui</code>-specific class names.
   * When set to <code>true</code> the <code>classCls</code> will be used as the baseCls
   * @default true
   * @see #ui
   * @see #classCls
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Widget.html#cfg-baseCls Original Ext JS documentation of 'baseCls'
   * @see #getBaseCls()
   * @see #setBaseCls()
   */
  public native function get baseCls():*;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set baseCls(value:*):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * Setting this config option adds or removes data bindings for other configs.
   * For example, to bind the <code>title</code> config:
   * <pre>
   *  var panel = Ext.create({
   *      xtype: 'panel',
   *      bind: {
   *          title: 'Hello {user.name}'
   *      }
   *  });
   * </pre>
   * <p>To dynamically add bindings:</p>
   * <pre>
   *  panel.setBind({
   *      title: 'Greetings {user.name}!'
   *  });
   * </pre>
   * <p>To remove bindings:</p>
   * <pre>
   *  panel.setBind({
   *      title: null
   *  });
   * </pre>
   * <p>The bind expressions are presented to <code>ext.app.ViewModel#bind()</code>. The
   * <code>ViewModel</code> instance is determined by <code>lookupViewModel</code>.</p>
   * <p><b>Note:</b> If bind is passed as a string, it will use the <code>ext.Component#defaultBindProperty</code>
   * for the binding.</p>
   * @see ext.app.ViewModel#bind()
   * @see #lookupViewModel()
   * @see ext.Component#defaultBindProperty
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.mixin.Bindable.html#cfg-bind Original Ext JS documentation of 'bind'
   * @see #getBind()
   * @see #setBind()
   */
  public native function get bind():*;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set bind(value:*):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * Enables or disables bordering on this component.
   * The following values are accepted:
   * <ul>
   * <li><code>null</code> or `true (default): Do nothing and allow the border to be specified by the theme.</li>
   * <li><code>false</code>: suppress the default border provided by the theme.</li>
   * </ul>
   * <p>Please note that enabling bordering via this config will not add a <code>border-color</code>
   * or <code>border-style</code> CSS property to the component; you provide the <code>border-color</code>
   * and <code>border-style</code> via CSS rule or <code>style</code> configuration
   * (if not already provide by the theme).</p>
   * <p><b><i>Using style:</i></b></p>
   * <pre>
   * Ext.Viewport.add({
   *     centered: true,
   *     width: 100,
   *     height: 100,
   *
   *     style: 'border: 1px solid blue;'
   *     // ...
   * });
   * </pre>
   * <p><b><i>Using CSS:</i></b></p>
   * <pre>
   * Ext.Viewport.add({
   *     centered: true,
   *     width: 100,
   *     height: 100,
   *
   *     cls: 'my-component'
   *     // ...
   * });
   * </pre>
   * <p>And your CSS file:</p>
   * <pre>
   * .my-component {
   *     border: 1px solid red;
   * }
   * </pre>
   * @see #style
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Widget.html#cfg-border Original Ext JS documentation of 'border'
   * @see #getBorder()
   * @see #setBorder()
   */
  public native function get border():Boolean;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set border(value:Boolean):void;

  /**
   * A CSS class to apply to the main element that will be inherited down the class
   * hierarchy. Subclasses may override this property on their prototype to add their
   * own CSS class in addition to the CSS classes inherited from ancestor classes via
   * the prototype chain. For example
   * <pre>
   * Ext.define('Foo', {
   *     extend: 'Ext.Widget',
   *     classCls: 'foo'
   * });
   *
   * Ext.define('Bar', {
   *     extend: 'Foo',
   *     classCls: 'bar'
   * });
   *
   * var bar = new Bar();
   *
   * console.log(bar.element.className); // outputs 'foo bar'
   * </pre>
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Widget.html#property-classCls Original Ext JS documentation of 'classCls'
   */
  public native function get classCls():*;

  /**
   * @private
   */
  public native function set classCls(value:*):void;

  /**
   * When set to <code>true</code> during widget class definition, that class will be the "root" for
   * <code>classCls</code> inheritance. Derived classes may set this to <code>true</code> to avoid
   * inheriting a <code>classCls</code> from their superclass.
   * @default true
   * @see #classCls
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Widget.html#property-classClsRoot Original Ext JS documentation of 'classClsRoot'
   */
  public native function get classClsRoot():*;

  /**
   * @private
   */
  public native function set classClsRoot(value:*):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * The CSS class to add to this widget's element, in
   * addition to the <code>baseCls</code>. In many cases, this property will be specified
   * by the derived widget class. See <code>userCls</code> for adding additional CSS
   * classes to widget instances (such as items in a <code>Ext.Container</code>).
   * @see #baseCls
   * @see #userCls
   * @see ext.container.Container
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Widget.html#cfg-cls Original Ext JS documentation of 'cls'
   * @see #getCls()
   * @see #setCls()
   */
  public native function get cls():String;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set cls(value:String):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * A string alias, a configuration object or an instance of a <code>ViewController</code> for
   * this container. Sample usage:
   * <pre>
   * Ext.define('MyApp.UserController', {
   *     alias: 'controller.user'
   * });
   *
   * Ext.define('UserContainer', {
   *     extend: 'Ext.container.container',
   *     controller: 'user'
   * });
   * // Or
   * Ext.define('UserContainer', {
   *     extend: 'Ext.container.container',
   *     controller: {
   *         type: 'user',
   *         someConfig: true
   *     }
   * });
   *
   * // Can also instance at runtime
   * var ctrl = new MyApp.UserController();
   * var view = new UserContainer({
   *     controller: ctrl
   * });
   * </pre>
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.mixin.Bindable.html#cfg-controller Original Ext JS documentation of 'controller'
   * @see #getController()
   * @see #setController()
   */
  public native function get controller():*;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set controller(value:*):void;

  /**
   * This property is used to determine the property of a <code>bind</code> config that is just
   * the value. For example, if <code>defaultBindProperty="value"</code>, then this shorthand
   * <code>bind</code> config:
   * <pre>
   *  bind: '{name}'
   * </pre>
   * <p>Is equivalent to this object form:</p>
   * <pre>
   *  bind: {
   *      value: '{name}'
   *  }
   * </pre>
   * <p>The <code>defaultBindProperty</code> is set to "value" for form fields and to "store" for
   * grids and trees.</p>
   * @see #bind
   * @see #defaultBindProperty
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.mixin.Bindable.html#property-defaultBindProperty Original Ext JS documentation of 'defaultBindProperty'
   */
  public native function get defaultBindProperty():String;

  /**
   * @private
   */
  public native function set defaultBindProperty(value:String):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * If <code>true</code>, this component will be the default scope (this pointer) for events
   * specified with string names so that the scope can be dynamically resolved. The
   * component will automatically become the defaultListenerScope if a
   * <code>controller</code> is specified.
   * <p>See the introductory docs for <code>ext.container.Container</code> for some sample
   * usages.</p>
   * <p><b>NOTE</b>: This value can only be reliably set at construction time. Setting it
   * after that time may not correctly rewire all of the potentially effected
   * listeners.</p>
   * @default false
   * @see #controller
   * @see ext.container.Container
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.mixin.Bindable.html#cfg-defaultListenerScope Original Ext JS documentation of 'defaultListenerScope'
   * @see #getDefaultListenerScope()
   * @see #setDefaultListenerScope()
   */
  public native function get defaultListenerScope():Boolean;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set defaultListenerScope(value:Boolean):void;

  /**
   * A configuration object for Ext.Element.create() that is used to create the Element
   * template. Supports all the standard options of a Ext.Element.create() config and
   * adds 2 additional options:
   * <ol>
   * <li>
   * <p><code>reference</code> - this option specifies a name for Element references. These
   * references names become properties of the Widget instance and refer to Ext.Element
   * instances that were created using the template:</p>
   * <p>element: {
   * reference: 'element',
   * children: [{
   * reference: 'innerElement'
   * }]
   * }</p>
   * </li>
   * </ol>
   * <p>After construction of a widget the reference elements are accessible as follows:</p>
   * <pre>
   * var foo = new FooWidget(),
   *     innerEl = foo.innerElement; // an Ext.Element that wraps the innerElement
   * </pre>
   * <p>The reference attribute is optional, but all Widgets must have a <code>'element'</code>
   * reference on some element within the template (usually the outermost one).</p>
   * <ol start="2">
   * <li>
   * <p><code>listeners</code> - a standard listeners object as specified by <code>ext.mixin.Observable</code>.</p>
   * <p>element: {
   * reference: 'element',
   * listeners: {
   * click: 'onClick'
   * },
   * children: [{
   * reference: 'innerElement',
   * listeners: {
   * click: 'onInnerClick'
   * }
   * }]
   * }</p>
   * </li>
   * </ol>
   * <p>Since listeners cannot be attached without an Ext.Element reference the <code>reference</code>
   * property MUST be specified in order to use <code>listeners</code>.</p>
   * <p>The Widget instance is used as the scope for all listeners specified in this way,
   * so it is invalid to use the <code>scope</code> option in the <code>listeners</code> config since it will
   * always be overwritten using <code>this</code>.</p>
   * @default {
   *     reference: 'element'
   * }
   * @see #reference
   * @see #listeners
   * @see ext.mixin.Observable
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Widget.html#property-element Original Ext JS documentation of 'element'
   */
  public native function get element():Object;

  /**
   * @private
   */
  public native function set element(value:Object):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * The height of this Component; must be a valid CSS length value, e.g: <code>300</code>, <code>100px</code>, <code>30%</code>, etc.
   * By default, if this is not explicitly set, this Component's element will simply have its own natural size.
   * If set to <code>auto</code>, it will set the width to <code>null</code> meaning it will have its own natural size.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Widget.html#cfg-height Original Ext JS documentation of 'height'
   * @see #getHeight()
   * @see #setHeight()
   */
  public native function get height():*;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set height(value:*):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * Whether or not this Component is hidden (its CSS <code>display</code> property is set to <code>none</code>).
   * <p>Defaults to <code>true</code> for <code>floated</code> Components.</p>
   * @see #floated
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Widget.html#cfg-hidden Original Ext JS documentation of 'hidden'
   * @see #getHidden()
   * @see #setHidden()
   */
  public native function get hidden():Boolean;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set hidden(value:Boolean):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * An object or array of objects that will provide custom functionality for this
   * component. If a string is provided or a string is one of the elements of the
   * array, that string is treated as the <code>type</code> alias. For example, "listpaging"
   * is the type alias for <code>Ext.plugin.ListPaging</code>. The full alias includes the
   * "plugin." prefix (i.e., 'plugin.listpaging').
   * <p>Plugins should derive from <code>ext.plugin.AbstractPlugin</code> but this is not required. The
   * only requirement for a valid plugin is that it contain an <code>init()</code> method that
   * accepts a reference to the owning component.</p>
   * <p>When a component is created, if any plugins are available, the component will
   * call the <code>init</code> method on each plugin,
   * passing a reference to itself. Each plugin can then call methods or respond to
   * events on the component as needed to provide its functionality.</p>
   * <p><b><i>Example code</i></b></p>
   * <p>A plugin by alias:</p>
   * <pre>
   *  var list = Ext.create({
   *      xtype: 'list',
   *      itemTpl: '&lt;div class="item"&gt;{title}&lt;/div&gt;',
   *      store: 'Items',
   *
   *      plugins: 'listpaging'
   *  });
   * </pre>
   * <p>Multiple plugins by alias:</p>
   * <pre>
   *  var list = Ext.create({
   *      xtype: 'list',
   *      itemTpl: '&lt;div class="item"&gt;{title}&lt;/div&gt;',
   *      store: 'Items',
   *
   *      plugins: ['listpaging', 'pullrefresh']
   *  });
   * </pre>
   * <p>Single plugin by class name with config options:</p>
   * <pre>
   *  var list = Ext.create({
   *      xtype: 'list',
   *      itemTpl: '&lt;div class="item"&gt;{title}&lt;/div&gt;',
   *      store: 'Items',
   *
   *      plugins: {
   *          type: 'listpaging',
   *          autoPaging: true
   *      }
   *  });
   * </pre>
   * <p>Multiple plugins by type and class name with config options:</p>
   * <pre>
   *  var list = Ext.create({
   *      xtype: 'list',
   *      itemTpl: '&lt;div class="item"&gt;{title}&lt;/div&gt;',
   *      store: 'Items',
   *
   *      plugins: [{
   *          xclass: 'Ext.plugin.PullRefresh',
   *          pullRefreshText: 'Pull to refresh...'
   *      }, {
   *          type: 'listpaging',
   *          autoPaging: true
   *      }]
   *  });
   * </pre>
   * @see ext.plugin.AbstractPlugin
   * @see ext.plugin.AbstractPlugin#init()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.mixin.Pluggable.html#cfg-plugins Original Ext JS documentation of 'plugins'
   * @see #getPlugins()
   * @see #setPlugins()
   */
  public native function get plugins():Array;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set plugins(value:Array):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * One or more names of config properties that this component should publish
   * to its ViewModel. Generally speaking, only properties defined in a class config
   * block (including ancestor config blocks and mixins) are eligible for publishing
   * to the viewModel. Some components override this and publish their most useful
   * configs by default.
   * <p><b>Note:</b> We'll discuss publishing properties <b>not</b> found in the config block below.</p>
   * <p>Values determined to be invalid by component (often form fields and model validations)
   * will not be published to the ViewModel.</p>
   * <p>This config uses the <code>reference</code> to determine the name of the data
   * object to place in the <code>ViewModel</code>. If <code>reference</code> is not set then this config
   * is ignored.</p>
   * <p>By using this config and <code>reference</code> you can bind configs between
   * components. For example:</p>
   * <pre>
   *  ...
   *      items: [{
   *          xtype: 'textfield',
   *          reference: 'somefield',  // component's name in the ViewModel
   *          publishes: 'value' // value is not published by default
   *      },{
   *          ...
   *      },{
   *          xtype: 'displayfield',
   *          bind: 'You have entered "{somefield.value}"'
   *      }]
   *  ...
   * </pre>
   * <p>Classes must provide this config as an Object:</p>
   * <pre>
   *  Ext.define('App.foo.Bar', {
   *      publishes: {
   *          foo: true,
   *          bar: true
   *      }
   *  });
   * </pre>
   * <p>This is required for the config system to properly merge values from derived
   * classes.</p>
   * <p>For instances this value can be specified as a value as show above or an array
   * or object as follows:</p>
   * <pre>
   *  {
   *      xtype: 'textfield',
   *      reference: 'somefield',
   *      publishes: [
   *          'value',
   *          'rawValue',
   *          'dirty'
   *      ]
   *  }
   *
   *  // This achieves the same result as the above array form.
   *  {
   *      xtype: 'textfield',
   *      reference: 'somefield',
   *      publishes: {
   *          value: true,
   *          rawValue: true,
   *          dirty: true
   *      }
   *  }
   * </pre>
   * <p>In some cases, users may want to publish a property to the viewModel that is not found in a class
   * config block. In these situations, you may utilize <code>publishState()</code> if the property has a
   * setter method. Let's use <code>setFieldLabel</code> as an example:</p>
   * <pre>
   *   setFieldLabel: function(fieldLabel) {
   *       this.callParent(arguments);
   *       this.publishState('fieldLabel', fieldLabel);
   *   }
   * </pre>
   * <p>With the above chunk of code, fieldLabel may now be published to the viewModel.</p>
   * @since 5.0.0
   * @see #reference
   * @see #publishState()
   * @see ext.form.Labelable#setFieldLabel()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.mixin.Bindable.html#cfg-publishes Original Ext JS documentation of 'publishes'
   * @see #getPublishes()
   * @see #setPublishes()
   */
  public native function get publishes():*;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set publishes(value:*):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * Specifies a name for this component inside its component hierarchy. This name
   * must be unique within its <code>view</code>
   * or its <code>ext.app.ViewController</code>. See the documentation in
   * <code>ext.container.Container</code> for more information about references.
   * <p><b>Note</b>: Valid identifiers start with a letter or underscore and are followed
   * by zero or more additional letters, underscores or digits. References are case
   * sensitive.</p>
   * @see ext.container.Container#referenceHolder
   * @see ext.app.ViewController
   * @see ext.container.Container
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.mixin.Bindable.html#cfg-reference Original Ext JS documentation of 'reference'
   * @see #getReference()
   * @see #setReference()
   */
  public native function get reference():String;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set reference(value:String):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * If provided this creates a new <code>Session</code> instance for this component. If this
   * is a <code>Container</code>, this will then be inherited by all child components.
   * <p>To create a new session you can specify <code>true</code>:</p>
   * <pre>
   *  Ext.create({
   *      xtype: 'viewport',
   *      session: true,
   *
   *      items: [{
   *          ...
   *      }]
   *  });
   * </pre>
   * <p>Alternatively, a config object can be provided:</p>
   * <pre>
   *  Ext.create({
   *      xtype: 'viewport',
   *      session: {
   *          ...
   *      },
   *
   *      items: [{
   *          ...
   *      }]
   *  });
   * </pre>
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.mixin.Bindable.html#cfg-session Original Ext JS documentation of 'session'
   * @see #getSession()
   * @see #setSession()
   */
  public native function get session():*;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set session(value:*):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * Additional CSS styles that will be rendered into an inline style attribute when
   * the widget is rendered.
   * <p>You can pass either a string syntax:</p>
   * <pre>
   * style: 'background:red'
   * </pre>
   * <p>Or by using an object:</p>
   * <pre>
   * style: {
   *     background: 'red'
   * }
   * </pre>
   * <p>When using the object syntax, you can define CSS Properties by using a string:</p>
   * <pre>
   * style: {
   *     'border-left': '1px solid red'
   * }
   * </pre>
   * <p>Although the object syntax is much easier to read, we suggest you to use the
   * string syntax for better performance.</p>
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Widget.html#cfg-style Original Ext JS documentation of 'style'
   * @see #getStyle()
   * @see #setStyle()
   */
  public native function get style():*;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set style(value:*):void;

  /**
   * An array of child elements to use as the children of the main element in the <code>element</code> template. Only used if "children" are not specified explicitly in the
   * <code>element</code> template.
   * @default []
   * @see #element
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Widget.html#property-template Original Ext JS documentation of 'template'
   */
  public native function get template():Array;

  /**
   * @private
   */
  public native function set template(value:Array):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * Emulates the behavior of the CSS
   * <i>touch-action</i>
   * property in a cross-browser compatible manner.
   * <p>Keys in this object are touch action names, and values are <code>false</code> to disable
   * a touch action or <code>true</code> to enable it. Accepted keys are:</p>
   * <ul>
   * <li><code>panX</code></li>
   * <li><code>panY</code></li>
   * <li><code>pinchZoom</code></li>
   * <li><code>doubleTapZoom</code></li>
   * </ul>
   * <p>All touch actions are enabled (<code>true</code>) by default, so it is usually only necessary
   * to specify which touch actions to disable. For example, the following disables
   * only horizontal scrolling and pinch-to-zoom on the component's main element:</p>
   * <pre>
   * touchAction: {
   *     panX: false,
   *     pinchZoom: false
   * }
   * </pre>
   * <p>Touch actions can be specified on reference elements using the reference element
   * name, for example:</p>
   * <pre>
   * // disables horizontal scrolling on the main element, and double-tap-zoom
   * // on the child element named "body"
   * touchAction: {
   *     panY: false
   *     body: {
   *         doubleTapZoom: false
   *     }
   * }
   * </pre>
   * <p>The primary motivation for setting the touch-action of an element is to prevent
   * the browser's default handling of a gesture such as pinch-to-zoom, or
   * drag-to-scroll, so that the application can implement its own handling of that
   * gesture on the element. Suppose, for example, a component has a custom drag
   * handler on its element and wishes to prevent horizontal scrolling of its container
   * while it is being dragged:</p>
   * <pre>
   * Ext.create('Ext.Widget', {
   *     touchAction: {
   *         panX: false
   *     },
   *     listeners: {
   *         drag: function(e) {
   *             // implement drag logic
   *         }
   *     }
   * });
   * </pre>
   * @see https://www.w3.org/TR/pointerevents/#the-touch-action-css-property touch-action
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Widget.html#cfg-touchAction Original Ext JS documentation of 'touchAction'
   * @see #getTouchAction()
   * @see #setTouchAction()
   */
  public native function get touchAction():Object;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set touchAction(value:Object):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * This object holds a map of <code>config</code> properties that will update their binding
   * as they are modified. For example, <code>value</code> is a key added by form fields. The
   * form of this config is the same as <code>publishes</code>.
   * <p>This config is defined so that updaters are not created and added for all
   * bound properties since most cannot be modified by the end-user and hence are
   * not appropriate for two-way binding.</p>
   * @see #publishes
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.mixin.Bindable.html#cfg-twoWayBindable Original Ext JS documentation of 'twoWayBindable'
   * @see #getTwoWayBindable()
   * @see #setTwoWayBindable()
   */
  public native function get twoWayBindable():*;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set twoWayBindable(value:*):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * The ui or uis to be used on this Component
   * <p>When a ui is configured, CSS class names are added to the <code>element</code>, created
   * by appending the ui name(s) to each <code>classCls</code> and/or <code>baseCls</code>.</p>
   * @see #element
   * @see #classCls
   * @see #baseCls
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Widget.html#cfg-ui Original Ext JS documentation of 'ui'
   * @see #getUi()
   * @see #setUi()
   */
  public native function get ui():*;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set ui(value:*):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * One or more CSS classes to add to the component's primary element. This config
   * is intended solely for use by the component instantiator (the "user"), not by
   * derived classes.
   * <p>For example:</p>
   * <pre>
   *  items: [{
   *      xtype: 'button',
   *      userCls: 'my-button'
   *  ...
   *  }]
   * </pre>
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Widget.html#cfg-userCls Original Ext JS documentation of 'userCls'
   * @see #getUserCls()
   * @see #setUserCls()
   */
  public native function get userCls():*;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set userCls(value:*):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * The <code>ViewModel</code> is a data provider for this component and its children. The
   * data contained in the <code>ViewModel</code> is typically used by adding <code>bind</code> configs
   * to the components that want present or edit this data.
   * <p>When set, the <code>ViewModel</code> is created and links to any inherited <code>viewModel</code>
   * instance from an ancestor container as the "parent". The <code>ViewModel</code> hierarchy,
   * once established, only supports creation or destruction of children. The
   * parent of a <code>ViewModel</code> cannot be changed on the fly.</p>
   * <p>If this is a root-level <code>ViewModel</code>, the data model connection is made to this
   * component's associated <code>ext.data.Session</code>. This is
   * determined by calling <code>getInheritedSession</code>.</p>
   * @see #bind
   * @see #viewModel
   * @see ext.data.Session
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.mixin.Bindable.html#cfg-viewModel Original Ext JS documentation of 'viewModel'
   * @see #getViewModel()
   * @see #setViewModel()
   */
  public native function get viewModel():ext.app.ViewModel;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set viewModel(value:ext.app.ViewModel):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * The width of this Component; must be a valid CSS length value, e.g: <code>300</code>, <code>100px</code>, <code>30%</code>, etc.
   * By default, if this is not explicitly set, this Component's element will simply have its own natural size.
   * If set to <code>auto</code>, it will set the width to <code>null</code> meaning it will have its own natural size.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Widget.html#cfg-width Original Ext JS documentation of 'width'
   * @see #getWidth()
   * @see #setWidth()
   */
  public native function get width():*;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set width(value:*):void;

  /**
   * @inheritDoc
   */
  public native function addPlugin(plugin:*):void;

  /**
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Widget.html#method-applyStyle Original Ext JS documentation of 'applyStyle'
   */
  protected native function applyStyle(style:*, oldStyle:*):void;

  /**
   * Destroys the Widget. This method should not be overridden in custom Widgets,
   * because it sets the flags and does final cleanup that must go last. Instead,
   * override <code>doDestroy()</code> method to add functionality at destruction time.
   * @see #doDestroy()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Widget.html#method-destroy Original Ext JS documentation of 'destroy'
   */
  override public native function destroy(...params):void;

  /**
   * @inheritDoc
   */
  public native function destroyPlugin(plugin:*):ext.plugin.AbstractPlugin;

  /**
   * Perform the actual destruction sequence. This is the method to override in your
   * subclasses to add steps specific to the destruction of custom Component or Widget.
   * <p>As a rule of thumb, subclasses should destroy their child Components, Elements,
   * and/or other objects before calling parent method. Any object references will be
   * nulled after this method has finished, to prevent the possibility of memory leaks.</p>
   * @since 6.2.0
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Widget.html#method-doDestroy Original Ext JS documentation of 'doDestroy'
   */
  public native function doDestroy():void;

  /**
   * @inheritDoc
   */
  public native function findPlugin(type:String):ext.plugin.AbstractPlugin;

  /**
   * Returns the value of <code>baseCls</code>.
   * @see #baseCls
   */
  public native function getBaseCls():*;

  /**
   * Returns the value of <code>bind</code>.
   * @see #bind
   */
  public native function getBind():*;

  /**
   * Returns the value of <code>border</code>.
   * @see #border
   */
  public native function getBorder():Boolean;

  /**
   * Returns the value of <code>cls</code>.
   * @see #cls
   */
  public native function getCls():String;

  /**
   * Returns the value of <code>controller</code>.
   * @see #controller
   */
  public native function getController():*;

  /**
   * Returns the value of <code>defaultListenerScope</code>.
   * @see #defaultListenerScope
   */
  public native function getDefaultListenerScope():Boolean;

  /**
   * A template method for modifying the <code>element</code> config before it is processed.
   * By default adds the result of <code>this.getTemplate()</code> as the <code>children</code> array of
   * <code>element</code> if <code>children</code> were not specified in the original
   * <code>element</code> config. Typically this method should not need to be implemented
   * in subclasses. Instead the <code>element</code> property should be use to configure
   * the element template for a given Widget subclass.
   * <p>This method is called once when the first instance of each Widget subclass is
   * created. The element config object that is returned is cached and used as the template
   * for all successive instances. The scope object for this method is the class prototype,
   * not the instance.</p>
   * @return the element config object
   * @see #element
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Widget.html#method-getElementConfig Original Ext JS documentation of 'getElementConfig'
   */
  protected native function getElementConfig():Object;

  /**
   * Returns the value of <code>height</code>.
   * @see #height
   */
  public native function getHeight():*;

  /**
   * Returns the value of <code>hidden</code>.
   * @see #hidden
   */
  public native function getHidden():Boolean;

  /**
   * @inheritDoc
   */
  public native function getInherited(inner:Boolean = false):Object;

  /**
   * @inheritDoc
   */
  public native function getInheritedConfig(property:String, skipThis:Boolean = false):*;

  /**
   * @inheritDoc
   */
  public native function getPlugin(id:String):ext.plugin.AbstractPlugin;

  /**
   * Returns the value of <code>plugins</code>.
   * @see #plugins
   */
  public native function getPlugins():Array;

  /**
   * Returns the value of <code>publishes</code>.
   * @see #publishes
   */
  public native function getPublishes():*;

  /**
   * Used by <code>ext.SComponentQuery</code>, and the <code>up</code>
   * method to find the owning Component in the linkage hierarchy.
   * <p>By default this returns the Container which contains this Component.</p>
   * <p>This may be overridden by Component authors who implement ownership hierarchies
   * which are not based upon ownerCt, such as BoundLists being owned by Fields or Menus
   * being owned by Buttons.</p>
   * @see ext.SComponentQuery
   * @see ext.Component#up()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.mixin.Inheritable.html#method-getRefOwner Original Ext JS documentation of 'getRefOwner'
   */
  protected native function getRefOwner():ext.Component;

  /**
   * Returns the value of <code>reference</code>.
   * @see #reference
   */
  public native function getReference():String;

  /**
   * Returns the value of <code>session</code>.
   * @see #session
   */
  public native function getSession():*;

  /**
   * Returns the height and width of the Component.
   * @return The current <code>height</code> and <code>width</code> of the Component.
   * <ul>
   * <li><code>width</code> : Number (optional)
   *
   * </li>
   * <li><code>height</code> : Number (optional)
   *
   * </li>
   * </ul>
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Widget.html#method-getSize Original Ext JS documentation of 'getSize'
   * @see #height
   * @see #width
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Widget.html#property-width Original Ext JS documentation of 'width'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Widget.html#property-height Original Ext JS documentation of 'height'
   */
  public native function getSize():Object;

  /**
   * Returns the value of <code>style</code>.
   * @see #style
   */
  public native function getStyle():*;

  /**
   * Returns the value of <code>touchAction</code>.
   * @see #touchAction
   */
  public native function getTouchAction():Object;

  /**
   * Returns the value of <code>twoWayBindable</code>.
   * @see #twoWayBindable
   */
  public native function getTwoWayBindable():*;

  /**
   * Returns the value of <code>ui</code>.
   * @see #ui
   */
  public native function getUi():*;

  /**
   * Returns the value of <code>userCls</code>.
   * @see #userCls
   */
  public native function getUserCls():*;

  /**
   * Returns the value of <code>viewModel</code>.
   * @see #viewModel
   */
  public native function getViewModel():*;

  /**
   * Returns the value of <code>width</code>.
   * @see #width
   */
  public native function getWidth():*;

  /**
   * Initializes the Element for this Widget instance. If this is the first time a
   * Widget of this type has been instantiated the <code>element</code> config will be
   * processed to create an Element. This Element is then cached on the prototype (see
   * afterCachedConfig) so that future instances can obtain their element by simply
   * cloning the Element that was cached by the first instance.
   * @see #element
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Widget.html#method-initElement Original Ext JS documentation of 'initElement'
   */
  protected native function initElement():void;

  /**
   * This method is called to initialize the <code>inheritedState</code> objects for this instance.
   * This amounts to typically copying certain properties from the instance to the given
   * object.
   * @since 5.0.0
   * @param inheritedState The state object for this instance.
   * @param inheritedStateInner This object is only provided for containers.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.mixin.Inheritable.html#method-initInheritedState Original Ext JS documentation of 'initInheritedState'
   */
  protected native function initInheritedState(inheritedState:Object, inheritedStateInner:Object = null):void;

  /**
   * Returns <code>true</code> if this Component is currently hidden.
   * @param deep <code>true</code> to check if this component
   * is hidden because a parent container is hidden. Alternatively, a reference to the
   * top-most parent at which to stop climbing.
   * @default false
   * @return <code>true</code> if currently hidden.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Widget.html#method-isHidden Original Ext JS documentation of 'isHidden'
   */
  public native function isHidden(deep:* = false):Boolean;

  /**
   * Returns <code>true</code> if this Component is currently visible.
   * @param deep <code>true</code> to check if this component
   * is visible and all parents are also visible.
   * @default false
   * @return <code>true</code> if currently visible.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Widget.html#method-isVisible Original Ext JS documentation of 'isVisible'
   */
  public native function isVisible(deep:Boolean = false):Boolean;

  /**
   * Tests whether or not this Component is of a specific xtype. This can test whether this Component is descended
   * from the xtype (default) or whether it is directly of the xtype specified (<code>shallow = true</code>).
   * &#42;&#42;If using your own subclasses, be aware that a Component must register its own xtype
   * to participate in determination of inherited xtypes.__
   * <p>For a list of all available xtypes, see the <code>ext.Component</code> header.</p>
   * <p>Example usage:</p>
   * <pre>
   * var t = new Ext.field.Text();
   * var isText = t.isXType('textfield'); // true
   * var isBoxSubclass = t.isXType('field'); // true, descended from Ext.field.Field
   * var isBoxInstance = t.isXType('field', true); // false, not a direct Ext.field.Field instance
   * </pre>
   * @param xtype The xtype to check for this Component.
   * @param shallow <code>false</code> to check whether this Component is descended from the xtype (this is
   * the default), or <code>true</code> to check whether this Component is directly of the specified xtype.
   * @return <code>true</code> if this component descends from the specified xtype, <code>false</code> otherwise.
   * @see ext.Component
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Widget.html#method-isXType Original Ext JS documentation of 'isXType'
   */
  public native function isXType(xtype:String, shallow:Boolean = false):Boolean;

  /**
   * @inheritDoc
   */
  public native function lookupController(skipThis:Boolean = false):ext.app.ViewController;

  /**
   * @inheritDoc
   */
  public native function lookupSession(skipThis:Boolean = false):ext.data.Session;

  /**
   * Gets a named template instance for this class. See <code>ext.XTemplate#getTpl()</code>.
   * @since 6.2.0
   * @param name The name of the property that holds the template.
   * @return The template, <code>null</code> if not found.
   * @see ext.XTemplate#getTpl()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Widget.html#method-lookupTpl Original Ext JS documentation of 'lookupTpl'
   */
  public native function lookupTpl(name:String):ext.XTemplate;

  /**
   * @inheritDoc
   */
  public native function lookupViewModel(skipThis:Boolean = false):ext.app.ViewModel;

  /**
   * Tests whether this Widget matches a <code>ext.SComponentQuery</code>
   * selector string.
   * @param selector The selector string to test against.
   * @return <code>true</code> if this Widget matches the selector.
   * @see ext.SComponentQuery
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Widget.html#method-is Original Ext JS documentation of 'is'
   */
  public native function matches(selector:String):Boolean;

  /**
   * Publish this components state to the <code>ViewModel</code>. If no arguments are given (or if
   * this is the first call), the entire state is published. This state is determined by
   * the <code>publishes</code> property.
   * <p>This method is called only by component authors.</p>
   * @since 5.0.0
   * @param property The name of the property to update.
   * @param value The value of <code>property</code>. Only needed if <code>property</code> is given.
   * @see #publishes
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.mixin.Bindable.html#method-publishState Original Ext JS documentation of 'publishState'
   */
  protected native function publishState(property:String = null, value:Object = null):void;

  /**
   * @inheritDoc
   */
  public native function removePlugin(plugin:*, destroy:Boolean = false):ext.plugin.AbstractPlugin;

  /**
   * Gets the Controller or Component that is used as the event root for this view.
   * @since 5.0.0
   * @param defaultScope (Default this) The default scope to return if none is found.
   * @default this
   * @return The default listener scope.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.mixin.Inheritable.html#method-resolveListenerScope Original Ext JS documentation of 'resolveListenerScope'
   */
  override protected native function resolveListenerScope(defaultScope:Object = null):Object;

  /**
   * Returns the default listener scope for a "satellite" of this component.
   * Used for resolving scope for observable objects that are not part of the normal
   * Container/Component hierarchy (for example, plugins)
   * @since 5.1.1
   * @return The listener scope
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.mixin.Inheritable.html#method-resolveSatelliteListenerScope Original Ext JS documentation of 'resolveSatelliteListenerScope'
   */
  protected native function resolveSatelliteListenerScope(satellite:ext.mixin.Observable, defaultScope:Object = null):Object;

  /**
   * Sets the value of <code>baseCls</code>.
   * @param baseCls The new value.
   * @see #baseCls
   */
  public native function setBaseCls(baseCls:*):void;

  /**
   * Sets the value of <code>bind</code>.
   * @param bind The new value.
   * @see #bind
   */
  public native function setBind(bind:*):void;

  /**
   * Sets the value of <code>border</code>.
   * @param border The new value.
   * @see #border
   */
  public native function setBorder(border:Boolean):void;

  /**
   * Sets the value of <code>cls</code>.
   * @param cls The new value.
   * @see #cls
   */
  public native function setCls(cls:String):void;

  /**
   * Sets the value of <code>controller</code>.
   * @param controller The new value.
   * @see #controller
   */
  public native function setController(controller:*):void;

  /**
   * Sets the value of <code>defaultListenerScope</code>.
   * @param defaultListenerScope The new value.
   * @see #defaultListenerScope
   */
  public native function setDefaultListenerScope(defaultListenerScope:Boolean):void;

  /**
   * Sets the value of <code>height</code>.
   * @param height The new value.
   * @see #height
   */
  public native function setHeight(height:*):void;

  /**
   * Sets the value of <code>hidden</code>.
   * @param hidden The new value.
   * @see #hidden
   */
  public native function setHidden(hidden:Boolean):void;

  /**
   * Sets the value of <code>plugins</code>.
   * @param plugins The new value.
   * @see #plugins
   */
  public native function setPlugins(plugins:Array):void;

  /**
   * Sets the value of <code>publishes</code>.
   * @param publishes The new value.
   * @see #publishes
   */
  public native function setPublishes(publishes:*):void;

  /**
   * Sets the value of <code>reference</code>.
   * @param reference The new value.
   * @see #reference
   */
  public native function setReference(reference:String):void;

  /**
   * Sets the value of <code>session</code>.
   * @param session The new value.
   * @see #session
   */
  public native function setSession(session:*):void;

  /**
   * Sets the size of the Component.
   * @param width The new width for the Component.
   * @param height The new height for the Component.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Widget.html#method-setSize Original Ext JS documentation of 'setSize'
   */
  public native function setSize(width:Number, height:Number):void;

  /**
   * Sets the value of <code>style</code>.
   * @param style The new value.
   * @see #style
   */
  public native function setStyle(style:*):void;

  /**
   * Sets the value of <code>touchAction</code>.
   * @param touchAction The new value.
   * @see #touchAction
   */
  public native function setTouchAction(touchAction:Object):void;

  /**
   * Sets the value of <code>twoWayBindable</code>.
   * @param twoWayBindable The new value.
   * @see #twoWayBindable
   */
  public native function setTwoWayBindable(twoWayBindable:*):void;

  /**
   * Sets the value of <code>ui</code>.
   * @param ui The new value.
   * @see #ui
   */
  public native function setUi(ui:*):void;

  /**
   * Sets the value of <code>userCls</code>.
   * @param userCls The new value.
   * @see #userCls
   */
  public native function setUserCls(userCls:*):void;

  /**
   * Sets the value of <code>viewModel</code>.
   * @param viewModel The new value.
   * @see #viewModel
   */
  public native function setViewModel(viewModel:*):void;

  /**
   * Sets the value of <code>width</code>.
   * @param width The new value.
   * @see #width
   */
  public native function setWidth(width:*):void;

  /**
   * Toggles the specified CSS class on this element (removes it if it already exists,
   * otherwise adds it).
   * @param className The CSS class to toggle.
   * @param state If specified as <code>true</code>, causes the class to be added. If
   * specified as <code>false</code>, causes the class to be removed.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Widget.html#method-toggleCls Original Ext JS documentation of 'toggleCls'
   */
  public native function toggleCls(className:String, state:Boolean = false):void;

  /**
   * Walks up the ownership hierarchy looking for an ancestor Component which matches
   * the passed simple selector.
   * <p>Example:</p>
   * <pre>
   * var owningTabPanel = grid.up('tabpanel');
   * </pre>
   * @param selector The simple selector to test.
   * @param limit This may be a selector upon which to stop the upward scan, or a limit of the number of steps, or Component reference to stop on.
   * @return The matching ancestor Container (or <code>undefined</code> if no match was found).
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Widget.html#method-up Original Ext JS documentation of 'up'
   */
  public native function up(selector:String = null, limit:* = undefined):ext.container.Container;

  /**
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Widget.html#method-updateHeight Original Ext JS documentation of 'updateHeight'
   */
  protected native function updateHeight(height:*):void;

  /**
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Widget.html#method-updateStyle Original Ext JS documentation of 'updateStyle'
   */
  protected native function updateStyle(style:*):void;

  /**
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.Widget.html#method-updateWidth Original Ext JS documentation of 'updateWidth'
   */
  protected native function updateWidth(width:*):void;
}
}