package ext.button {
import ext.container.Container;

[Uses("ext.container.Container")]
[Uses("ext.mixin.Queryable")]
[Uses("ext.Base")]
[Uses("ext.Component")]
[Uses("ext.util.Animate")]
[Uses("ext.util.ElementContainer")]
[Uses("ext.util.Focusable")]
[Uses("ext.mixin.ComponentDelegation")]
[Uses("ext.Mixin")]
[Uses("ext.mixin.Inheritable")]
[Uses("ext.util.Positionable")]
[Uses("ext.mixin.Bindable")]
[Uses("ext.mixin.Keyboard")]
[Uses("ext.mixin.Observable")]
[Uses("ext.mixin.Identifiable")]
[Uses("ext.state.Stateful")]
[Uses("ext.mixin.Accessible")]
[Uses("ext.util.Renderable")]
[Uses("ext.util.Floating")]
[Uses("ext.mixin.Container")]
[Native("Ext.button.Segmented", require)]
/**
 * @see ext.button.events.SegmentedButton_newValue_oldValueEvent.CHANGE
 * @eventType ext.button.events.SegmentedButton_newValue_oldValueEvent.CHANGE
 */
[Event(name = 'onChange', type = 'ext.button.events.SegmentedButton_newValue_oldValueEvent')]
/**
 * @see ext.button.events.SegmentedButton_button_isPressedEvent.TOGGLE
 * @eventType ext.button.events.SegmentedButton_button_isPressedEvent.TOGGLE
 */
[Event(name = 'onToggle', type = 'ext.button.events.SegmentedButton_button_isPressedEvent')]
/**
 * SegmentedButton is a container for a group of <code>ext.button.Button</code>s. You
 * may populate the segmented button's children by adding buttons to the items config. The segmented
 * button's children enjoy the same customizations as regular buttons, such as
 * menu, tooltip, etc. You can see usages of the various configuration
 * possibilities in the example below.
 * <p><b>Example:</b></p>
 * <pre>
 * Ext.create('Ext.button.Segmented', {
 *      renderTo: Ext.getBody(),
 *      allowMultiple: true,
 *      items: [{
 *           text: 'Segment Item 1',
 *           menu: [{
 *               text: 'Menu Item 1'
 *           }]
 *      },{
 *           text: 'Segment Item 2',
 *           tooltip: 'My custom tooltip'
 *      },{
 *           text: 'Segment Item 3'
 *      }],
 *      listeners: {
 *           toggle: function(container, button, pressed) {
 *                console.log("User toggled the '" + button.text + "' button: " + (pressed ? 'on' : 'off'));
 *           }
 *      }
 * });
 * </pre>
 * @see ext.button.Button
 * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.button.Segmented.html Original Ext JS documentation of 'Ext.button.Segmented'
 */
public class SegmentedButton extends ext.container.Container {
  /**
   * @param config @inheritDoc
   */
  public function SegmentedButton(config:ext.button.SegmentedButton = null) {
    super();
  }

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * Allow toggling the pressed state of each button.
   * Only applicable when <code>allowMultiple</code> is <code>false</code>.
   * @default false
   * @see #allowMultiple
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.button.Segmented.html#cfg-allowDepress Original Ext JS documentation of 'allowDepress'
   * @see #getAllowDepress()
   * @see #setAllowDepress()
   */
  public native function get allowDepress():Boolean;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set allowDepress(value:Boolean):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * Allow multiple pressed buttons.
   * @default false
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.button.Segmented.html#cfg-allowMultiple Original Ext JS documentation of 'allowMultiple'
   * @see #getAllowMultiple()
   * @see #setAllowMultiple()
   */
  public native function get allowMultiple():Boolean;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set allowMultiple(value:Boolean):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * True to enable pressed/not pressed toggling.
   * @default true
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.button.Segmented.html#cfg-allowToggle Original Ext JS documentation of 'allowToggle'
   * @see #getAllowToggle()
   * @see #setAllowToggle()
   */
  public native function get allowToggle():Boolean;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set allowToggle(value:Boolean):void;

  /**
   * This property is used to determine the property of a <code>bind</code> config that is just
   * the value. For example, if <code>defaultBindProperty="value"</code>, then this shorthand
   * <code>bind</code> config:
   * <pre>
   *  bind: '{name}'
   * </pre>
   * <p>Is equivalent to this object form:</p>
   * <pre>
   *  bind: {
   *      value: '{name}'
   *  }
   * </pre>
   * <p>The <code>defaultBindProperty</code> is set to "value" for form fields and to "store" for
   * grids and trees.</p>
   * @default 'value'
   * @see #bind
   * @see #defaultBindProperty
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.button.Segmented.html#property-defaultBindProperty Original Ext JS documentation of 'defaultBindProperty'
   */
  override public native function get defaultBindProperty():String;

  /**
   * @private
   */
  override public native function set defaultBindProperty(value:String):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * Default <code>ui</code> to use for buttons in this segmented button.
   * Buttons can override this default by specifying their own UI
   * @default 'default'
   * @see ext.Component#ui
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.button.Segmented.html#cfg-defaultUI Original Ext JS documentation of 'defaultUI'
   * @see #getDefaultUI()
   * @see #setDefaultUI()
   */
  public native function get defaultUI():String;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set defaultUI(value:String):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * If <code>allowMultiple</code> is <code>true</code>, this config may be set to <code>true</code> to indicate that at least
   * one button in the set must remain pressed at all times.
   * <p>If no <code>value</code> is configured, and no child buttons are configured <code>pressed</code>, the first child
   * button is set <code>pressed: true</code></p>
   * @default false
   * @see #allowMultiple
   * @see #value
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.button.Segmented.html#cfg-forceSelection Original Ext JS documentation of 'forceSelection'
   * @see #getForceSelection()
   * @see #setForceSelection()
   */
  public native function get forceSelection():Boolean;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set forceSelection(value:Boolean):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * The value of this button. When <code>allowMultiple</code> is <code>false</code>, value is a
   * String or Number. When <code>allowMultiple</code> is <code>true</code>, value is an array
   * of values. A value corresponds to a child button's <code>value</code>, or its index if no child button values match the given value.
   * <p>Using the <code>value</code> config of the child buttons with single toggle:</p>
   * <p><b>Example:</b></p>
   * <pre>
   * var button = Ext.create('Ext.button.Segmented', {
   *     renderTo: Ext.getBody(),
   *     value: 'optTwo', // begin with "Option Two" selected
   *     items: [{
   *         text: 'Option One',
   *         value: 'optOne'
   *     }, {
   *         text: 'Option Two',
   *         value: 'optTwo'
   *     }, {
   *         text: 'Option Three',
   *         value:  'optThree'
   *     }]
   * });
   *
   * console.log(button.getValue()); // optTwo
   *
   * // Sets the value to optOne, and sets the pressed state of the "Option One" button
   * button.setValue('optOne');
   *
   * console.log(button.getValue()); // optOne
   * </pre>
   * <p>Using multiple toggle, and index-based values:</p>
   * <p><b>Example:</b></p>
   * <pre>
   * var button = Ext.create('Ext.button.Segmented', {
   *     renderTo: Ext.getBody(),
   *     allowMultiple: true
   *     value: [1, 2], // begin with "Option Two" and "Option Three" selected
   *     items: [{
   *         text: 'Option One'
   *     }, {
   *         text: 'Option Two'
   *     }, {
   *         text: 'Option Three'
   *     }]
   * });
   *
   * // Sets value to [0, 2], and sets pressed state of "Option One" and "Option Three"
   * button.setValue([0, 2]);
   *
   * console.log(button.getValue()); // [0, 2]
   *
   * // Remove all pressed buttons, and set value to null
   * button.setValue(null);
   * </pre>
   * @see #allowMultiple
   * @see ext.button.Button#value
   * @see #value
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.button.Segmented.html#cfg-value Original Ext JS documentation of 'value'
   * @see #getValue()
   * @see #setValue()
   */
  public native function get value():*;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set value(value:*):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * True to align the buttons vertically
   * @default false
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.button.Segmented.html#cfg-vertical Original Ext JS documentation of 'vertical'
   * @see #getVertical()
   * @see #setVertical()
   */
  public native function get vertical():Boolean;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set vertical(value:Boolean):void;

  /**
   * Returns the value of <code>allowDepress</code>.
   * @see #allowDepress
   */
  public native function getAllowDepress():Boolean;

  /**
   * Returns the value of <code>allowMultiple</code>.
   * @see #allowMultiple
   */
  public native function getAllowMultiple():Boolean;

  /**
   * Returns the value of <code>allowToggle</code>.
   * @see #allowToggle
   */
  public native function getAllowToggle():Boolean;

  /**
   * Returns the value of <code>defaultUI</code>.
   * @see #defaultUI
   */
  public native function getDefaultUI():String;

  /**
   * Returns the value of <code>forceSelection</code>.
   * @see #forceSelection
   */
  public native function getForceSelection():Boolean;

  /**
   * Returns the value of <code>value</code>.
   * @see #value
   */
  public native function getValue():*;

  /**
   * Returns the value of <code>vertical</code>.
   * @see #vertical
   */
  public native function getVertical():Boolean;

  /**
   * Sets the value of <code>allowDepress</code>.
   * @param allowDepress The new value.
   * @see #allowDepress
   */
  public native function setAllowDepress(allowDepress:Boolean):void;

  /**
   * Sets the value of <code>allowMultiple</code>.
   * @param allowMultiple The new value.
   * @see #allowMultiple
   */
  public native function setAllowMultiple(allowMultiple:Boolean):void;

  /**
   * Sets the value of <code>allowToggle</code>.
   * @param allowToggle The new value.
   * @see #allowToggle
   */
  public native function setAllowToggle(allowToggle:Boolean):void;

  /**
   * Sets the value of <code>defaultUI</code>.
   * @param defaultUI The new value.
   * @see #defaultUI
   */
  public native function setDefaultUI(defaultUI:String):void;

  /**
   * Sets the value of <code>forceSelection</code>.
   * @param forceSelection The new value.
   * @see #forceSelection
   */
  public native function setForceSelection(forceSelection:Boolean):void;

  /**
   * Sets the value of <code>value</code>.
   * @param value The new value.
   * @see #value
   */
  public native function setValue(value:*):void;

  /**
   * Sets the value of <code>vertical</code>.
   * @param vertical The new value.
   * @see #vertical
   */
  public native function setVertical(vertical:Boolean):void;
}
}