package ext.data.reader {

[Uses("ext.data.reader.JsonReader")]
[Uses("ext.data.reader.DataReader")]
[Uses("ext.mixin.Factoryable")]
[Uses("ext.Base")]
[Uses("ext.mixin.Observable")]
[Uses("ext.Mixin")]
[Uses("ext.mixin.Identifiable")]
[Native("Ext.data.reader.Array", require)]
/**
 * Data reader class to create an Array of <code>ext.data.Model</code> objects from an Array.
 *  Each element of that Array represents a row of data fields. The
 *  fields are pulled into a Record object using as a subscript, the <code>mapping</code> property
 *  of the field definition if it exists, or the field's ordinal position in the definition.
 *  <p><u>Example code:</u></p>
 * <pre>
 *
 * Employee = Ext.define('Employee', {
 *     extend: 'Ext.data.Model',
 *     fields: [
 *         'id',
 *         {name: 'name', mapping: 1},         // "mapping" only needed if an "id" field is present which
 *         {name: 'occupation', mapping: 2}    // precludes using the ordinal position as the index.
 *     ]
 * });
 *
 * var myReader = new Ext.data.reader.Array({
 *     model: 'Employee'
 * }, Employee);
 * </pre>
 *  <p>This would consume an Array like this:</p>
 * <pre>
 *
 * [ [1, 'Bill', 'Gardener'], [2, 'Ben', 'Horticulturalist'] ]
 * </pre>
 * @see ext.data.Model
 * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.data.reader.Array.html Original Ext JS documentation of 'Ext.data.reader.Array'
 */
public class ArrayReader extends ext.data.reader.JsonReader {
  /**
   * Create a new ArrayReader
   * @param meta Metadata configuration options.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.data.reader.Array.html#method-constructor Original Ext JS documentation of 'constructor'
   */
  public function ArrayReader(meta:Object) {
    super();
  }

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.data.reader.Array.html#cfg-preserveRawData Original Ext JS documentation of 'preserveRawData'
   * @see #getPreserveRawData()
   * @see #setPreserveRawData()
   */
  override public native function get preserveRawData():Boolean;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  override public native function set preserveRawData(value:Boolean):void;

  /**
   * Returns the value of <code>preserveRawData</code>.
   * @see #preserveRawData
   */
  override public native function getPreserveRawData():Boolean;

  /**
   * Sets the value of <code>preserveRawData</code>.
   * @param preserveRawData The new value.
   * @see #preserveRawData
   */
  override public native function setPreserveRawData(preserveRawData:Boolean):void;
}
}