package ext.data.validator {

[Uses("ext.data.validator.BoundValidator")]
[Uses("ext.data.validator.Validator")]
[Uses("ext.mixin.Factoryable")]
[Uses("ext.Base")]
[Native("Ext.data.validator.Range", require)]
/**
 * Validates that the the value is between a <code>min</code> and <code>max</code>.
 * @see #min
 * @see #max
 * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.data.validator.Range.html Original Ext JS documentation of 'Ext.data.validator.Range'
 */
public class RangeValidator extends ext.data.validator.BoundValidator {
  /**
   * @param config @inheritDoc
   */
  public function RangeValidator(config:ext.data.validator.RangeValidator = null) {
    super();
  }

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * The maximum value.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.data.validator.Range.html#cfg-max Original Ext JS documentation of 'max'
   * @see #getMax()
   * @see #setMax()
   */
  override public native function get max():Number;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  override public native function set max(value:Number):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * The minimum value.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.data.validator.Range.html#cfg-min Original Ext JS documentation of 'min'
   * @see #getMin()
   * @see #setMin()
   */
  override public native function get min():Number;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  override public native function set min(value:Number):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * The error message to return when the value is not numeric.
   * @default 'Must be numeric'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.data.validator.Range.html#cfg-nanMessage Original Ext JS documentation of 'nanMessage'
   * @see #getNanMessage()
   * @see #setNanMessage()
   */
  public native function get nanMessage():String;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set nanMessage(value:String):void;

  /**
   * Returns the value of <code>max</code>.
   * @see #max
   */
  override public native function getMax():Number;

  /**
   * Returns the value of <code>min</code>.
   * @see #min
   */
  override public native function getMin():Number;

  /**
   * Returns the value of <code>nanMessage</code>.
   * @see #nanMessage
   */
  public native function getNanMessage():String;

  /**
   * Sets the value of <code>max</code>.
   * @param max The new value.
   * @see #max
   */
  override public native function setMax(max:Number):void;

  /**
   * Sets the value of <code>min</code>.
   * @param min The new value.
   * @see #min
   */
  override public native function setMin(min:Number):void;

  /**
   * Sets the value of <code>nanMessage</code>.
   * @param nanMessage The new value.
   * @see #nanMessage
   */
  public native function setNanMessage(nanMessage:String):void;
}
}