package ext.direct {
import ext.mixin.Observable;

[Uses("ext.mixin.Observable")]
[Uses("ext.Mixin")]
[Uses("ext.Base")]
[Uses("ext.mixin.Identifiable")]
[Native("Ext.direct.Provider", require)]
/**
 * @see ext.direct.events.ProviderEvent.CONNECT
 * @eventType ext.direct.events.ProviderEvent.CONNECT
 */
[Event(name = 'onConnect', type = 'ext.direct.events.ProviderEvent')]
/**
 * @see ext.direct.events.Provider_eEvent.DATA
 * @eventType ext.direct.events.Provider_eEvent.DATA
 */
[Event(name = 'onData', type = 'ext.direct.events.Provider_eEvent')]
/**
 * @see ext.direct.events.ProviderEvent.DISCONNECT
 * @eventType ext.direct.events.ProviderEvent.DISCONNECT
 */
[Event(name = 'onDisconnect', type = 'ext.direct.events.ProviderEvent')]
/**
 * @see ext.direct.events.Provider_eEvent.EXCEPTION
 * @eventType ext.direct.events.Provider_eEvent.EXCEPTION
 */
[Event(name = 'onException', type = 'ext.direct.events.Provider_eEvent')]
/**
 * Ext.direct.Provider is an abstract class meant to be extended.
 * <p>For example Ext JS implements the following subclasses:</p>
 * <pre>
 * Provider
 * |
 * +---JsonProvider
 *     |
 *     +---PollingProvider
 *     |
 *     +---RemotingProvider
 * </pre>
 * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.direct.Provider.html Original Ext JS documentation of 'Ext.direct.Provider'
 */
public class Provider extends ext.mixin.Observable {
  /**
   * Check if the passed configuration object contains enough
   * information to construct a Provider.
   * @return <code>true</code> if config is sufficient, <code>false</code> otherwise.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.direct.Provider.html#static-method-checkConfig Original Ext JS documentation of 'checkConfig'
   */
  public static native function checkConfig(config:Object):Boolean;

  /**
   * @param config @inheritDoc
   */
  public function Provider(config:ext.direct.Provider = null) {
    super();
  }

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * An object containing default headers for every Ajax request made by this Provider.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.direct.Provider.html#cfg-headers Original Ext JS documentation of 'headers'
   * @see #getHeaders()
   * @see #setHeaders()
   */
  public native function get headers():Object;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set headers(value:Object):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * The unique id of the provider (defaults to an <i>auto-assigned id</i>).
   * You should assign an id if you need to be able to access the provider later and you do
   * not have an object reference available, for example:
   * <pre>
   *  Ext.direct.Manager.addProvider({
   *      type: 'polling',
   *      url:  'php/poll.php',
   *      id:   'poll-provider'
   *  });
   *  var p = <code>ext.direct.SDirectManager</code>.<code>getProvider</code>('poll-provider');
   * p.disconnect();
   * </pre>
   * @see ext.SExt#id() auto-assigned id
   * @see ext.direct.SDirectManager
   * @see ext.direct.SDirectManager#getProvider()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.direct.Provider.html#cfg-id Original Ext JS documentation of 'id'
   * @see #getId()
   */
  public native function get id():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set id(value:String):void;

  [ArrayElementType("String")]
  [ExtConfig]
  /**
   * List of Provider events that should be relayed by <code>ext.direct.SDirectManager</code>.
   * 'data' event is always relayed.
   * @see ext.direct.SDirectManager
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.direct.Provider.html#cfg-relayedEvents Original Ext JS documentation of 'relayedEvents'
   */
  public native function get relayedEvents():Array;

  [ExtConfig]
  /**
   * @private
   */
  public native function set relayedEvents(value:Array):void;

  /**
   * Connect the provider and start its service.
   * Provider will fire <code>connect</code> event upon successful connection.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.direct.Provider.html#method-connect Original Ext JS documentation of 'connect'
   */
  public native function connect():void;

  /**
   * Disconnect the provider and stop its service.
   * Provider will fire <code>disconnect</code> event upon successful disconnect.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.direct.Provider.html#method-disconnect Original Ext JS documentation of 'disconnect'
   */
  public native function disconnect(force:*):void;

  /**
   * Do connection setup. This is a template method.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.direct.Provider.html#method-doConnect Original Ext JS documentation of 'doConnect'
   */
  protected native function doConnect():void;

  /**
   * Do connection teardown. This is a template method.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.direct.Provider.html#method-doDisconnect Original Ext JS documentation of 'doDisconnect'
   */
  protected native function doDisconnect():void;

  /**
   * Returns the value of <code>headers</code>.
   * @see #headers
   */
  public native function getHeaders():Object;

  /**
   * Returns whether or not the server-side is currently connected.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.direct.Provider.html#method-isConnected Original Ext JS documentation of 'isConnected'
   */
  public native function isConnected():void;

  /**
   * Sets the value of <code>headers</code>.
   * @param headers The new value.
   * @see #headers
   */
  public native function setHeaders(headers:Object):void;
}
}