package ext.form.field {
import ext.Component;
import ext.dom.Element;
import ext.form.ILabelable;
import js.HTMLElement;

[Uses("ext.Component")]
[Uses("ext.form.Labelable")]
[Uses("ext.form.field.Field")]
[Uses("ext.Mixin")]
[Uses("ext.Base")]
[Uses("ext.util.Animate")]
[Uses("ext.util.ElementContainer")]
[Uses("ext.util.Focusable")]
[Uses("ext.mixin.ComponentDelegation")]
[Uses("ext.mixin.Inheritable")]
[Uses("ext.util.Positionable")]
[Uses("ext.mixin.Bindable")]
[Uses("ext.mixin.Keyboard")]
[Uses("ext.mixin.Observable")]
[Uses("ext.mixin.Identifiable")]
[Uses("ext.state.Stateful")]
[Uses("ext.mixin.Accessible")]
[Uses("ext.util.Renderable")]
[Uses("ext.util.Floating")]
[Native("Ext.form.field.Base", require)]
/**
 * @see ext.form.field.events.BaseField_errorEvent.ERROR_CHANGE
 * @eventType ext.form.field.events.BaseField_errorEvent.ERROR_CHANGE
 */
[Event(name = 'onErrorChange', type = 'ext.form.field.events.BaseField_errorEvent')]
/**
 * @see ext.form.field.events.BaseField_newValue_oldValueEvent.CHANGE
 * @eventType ext.form.field.events.BaseField_newValue_oldValueEvent.CHANGE
 */
[Event(name = 'onChange', type = 'ext.form.field.events.BaseField_newValue_oldValueEvent')]
/**
 * @see ext.form.field.events.BaseField_isDirtyEvent.DIRTY_CHANGE
 * @eventType ext.form.field.events.BaseField_isDirtyEvent.DIRTY_CHANGE
 */
[Event(name = 'onDirtyChange', type = 'ext.form.field.events.BaseField_isDirtyEvent')]
/**
 * @see ext.form.field.events.BaseField_isValidEvent.VALIDITY_CHANGE
 * @eventType ext.form.field.events.BaseField_isValidEvent.VALIDITY_CHANGE
 */
[Event(name = 'onValidityChange', type = 'ext.form.field.events.BaseField_isValidEvent')]
/**
 * @see ext.form.field.events.BaseField_eEvent.SPECIAL_KEY
 * @eventType ext.form.field.events.BaseField_eEvent.SPECIAL_KEY
 */
[Event(name = 'onSpecialKey', type = 'ext.form.field.events.BaseField_eEvent')]
/**
 * @see ext.form.field.events.BaseField_ReadEvent.WRITEABLE_CHANGE
 * @eventType ext.form.field.events.BaseField_ReadEvent.WRITEABLE_CHANGE
 */
[Event(name = 'onWriteableChange', type = 'ext.form.field.events.BaseField_ReadEvent')]
/**
 * Base class for form fields that provides default event handling, rendering, and other common functionality
 * needed by all form field types. Utilizes the <code>ext.form.field.Field</code> mixin for value handling and validation,
 * and the <code>ext.form.Labelable</code> mixin to provide label and error message display.
 * <p>In most cases you will want to use a subclass, such as <code>ext.form.field.TextField</code> or <code>ext.form.field.Checkbox</code>,
 * rather than creating instances of this class directly. However if you are implementing a custom form field,
 * using this as the parent class is recommended.</p>
 * <p><b>Values and Conversions</b></p>
 * <p>Because Base implements the Field mixin, it has a main value that can be initialized with the
 * <code>value</code> config and manipulated via the <code>getValue()</code> and <code>setValue()</code> methods. This main
 * value can be one of many data types appropriate to the current field, for instance a <code>ext.form.field.DateField</code>
 * field would use a JavaScript Date object as its value type. However, because the field is rendered as a HTML
 * input, this value data type can not always be directly used in the rendered field.</p>
 * <p>Therefore Base introduces the concept of a "raw value". This is the value of the rendered HTML input field,
 * and is normally a String. The <code>getRawValue()</code> and <code>setRawValue()</code> methods can be used to directly
 * work with the raw value, though it is recommended to use getValue and setValue in most cases.</p>
 * <p>Conversion back and forth between the main value and the raw value is handled by the <code>valueToRaw()</code> and
 * <code>rawToValue()</code> methods. If you are implementing a subclass that uses a non-String value data type, you
 * should override these methods to handle the conversion.</p>
 * <p><b>Rendering</b></p>
 * <p>The content of the field body is defined by the <code>fieldSubTpl</code> XTemplate, with its argument data
 * created by the <code>getSubTplData()</code> method. Override this template and/or method to create custom
 * field renderings.</p>
 * @see ext.form.field.Field
 * @see ext.form.Labelable
 * @see ext.form.field.TextField
 * @see ext.form.field.Checkbox
 * @see #value
 * @see #getValue()
 * @see #setValue()
 * @see ext.form.field.DateField
 * @see #getRawValue()
 * @see #setRawValue()
 * @see #valueToRaw()
 * @see #rawToValue()
 * @see #fieldSubTpl
 * @see #getSubTplData()
 * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html Original Ext JS documentation of 'Ext.form.field.Base'
 */
public class BaseField extends ext.Component implements ext.form.ILabelable, ext.form.field.IField {
  /**
   * @param config @inheritDoc
   */
  public function BaseField(config:ext.form.field.BaseField = null) {
    super();
  }

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * If specified, then the component will be displayed with this value as its active error when first rendered. Use
   * <code>setActiveError()</code> or <code>unsetActiveError()</code> to change it after component creation.
   * @see #setActiveError()
   * @see #unsetActiveError()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.Labelable.html#cfg-activeError Original Ext JS documentation of 'activeError'
   * @see #getActiveError()
   */
  public native function get activeError():String;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set activeError(value:String):void;

  [ExtConfig]
  /**
   * The template used to format the Array of error messages passed to <code>setActiveErrors()</code> into a single HTML
   * string. if the <code>msgTarget</code> is title, it defaults to a list separated by new lines. Otherwise, it
   * renders each message as an item in an unordered list.
   * @see #setActiveErrors()
   * @see #msgTarget
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.Labelable.html#cfg-activeErrorsTpl Original Ext JS documentation of 'activeErrorsTpl'
   */
  public native function get activeErrorsTpl():*;

  [ExtConfig]
  /**
   * @private
   */
  public native function set activeErrorsTpl(value:*):void;

  [ExtConfig]
  /**
   * An optional string or <code>XTemplate</code> configuration to insert in the field markup
   * at the end of the input containing element. If an <code>XTemplate</code> is used, the component's <i>render data</i>
   * serves as the context.
   * @see ext.Component#renderData render data
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.Labelable.html#cfg-afterBodyEl Original Ext JS documentation of 'afterBodyEl'
   */
  public native function get afterBodyEl():*;

  [ExtConfig]
  /**
   * @private
   */
  public native function set afterBodyEl(value:*):void;

  [ExtConfig]
  /**
   * An optional string or <code>XTemplate</code> configuration to insert in the field markup
   * after the label text. If an <code>XTemplate</code> is used, the component's <i>render data</i>
   * serves as the context.
   * @see ext.Component#renderData render data
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.Labelable.html#cfg-afterLabelTextTpl Original Ext JS documentation of 'afterLabelTextTpl'
   */
  public native function get afterLabelTextTpl():*;

  [ExtConfig]
  /**
   * @private
   */
  public native function set afterLabelTextTpl(value:*):void;

  [ExtConfig]
  /**
   * An optional string or <code>XTemplate</code> configuration to insert in the field markup
   * after the label element. If an <code>XTemplate</code> is used, the component's <i>render data</i>
   * serves as the context.
   * @see ext.Component#renderData render data
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.Labelable.html#cfg-afterLabelTpl Original Ext JS documentation of 'afterLabelTpl'
   */
  public native function get afterLabelTpl():*;

  [ExtConfig]
  /**
   * @private
   */
  public native function set afterLabelTpl(value:*):void;

  [ExtConfig]
  /**
   * An optional string or <code>XTemplate</code> configuration to insert in the field markup
   * after the <i>subTpl markup</i>. If an <code>XTemplate</code> is used, the
   * component's <i>render data</i> serves as the context.
   * @see #getSubTplMarkup() subTpl markup
   * @see ext.Component#renderData render data
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.Labelable.html#cfg-afterSubTpl Original Ext JS documentation of 'afterSubTpl'
   */
  public native function get afterSubTpl():*;

  [ExtConfig]
  /**
   * @private
   */
  public native function set afterSubTpl(value:*):void;

  [ExtConfig]
  /**
   * Localized announcement text for validation errors. This text
   * will be used by Assistive Technologies such as screen readers to alert the users when
   * field validation fails.
   * <p>This config is used with <code>ext.SStringUtil#format()</code>. '{0}' will be replaced with the actual
   * error message(s), '{1}' will be replaced with field label.</p>
   * @default 'Input error. {0}.'
   * @see ext.SStringUtil#format()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.Labelable.html#cfg-ariaErrorText Original Ext JS documentation of 'ariaErrorText'
   */
  public native function get ariaErrorText():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set ariaErrorText(value:String):void;

  [ExtConfig]
  /**
   * Optional text description for this object. This text will be
   * announced to Assistive Technology users when the object is focused.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.Labelable.html#cfg-ariaHelp Original Ext JS documentation of 'ariaHelp'
   */
  public native function get ariaHelp():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set ariaHelp(value:String):void;

  [ExtConfig]
  /**
   * Whether to adjust the component's body width to make room for 'side'
   * <i>error messages</i>.
   * @default true
   * @see #msgTarget error messages
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.Labelable.html#cfg-autoFitErrors Original Ext JS documentation of 'autoFitErrors'
   */
  public native function get autoFitErrors():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set autoFitErrors(value:Boolean):void;

  [ExtConfig]
  /**
   * The CSS class to be applied to the body content element.
   * @default Ext.baseCSSPrefix + 'form-item-body'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.Labelable.html#cfg-baseBodyCls Original Ext JS documentation of 'baseBodyCls'
   */
  public native function get baseBodyCls():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set baseBodyCls(value:String):void;

  [ExtConfig]
  /**
   * An optional string or <code>XTemplate</code> configuration to insert in the field markup
   * at the beginning of the input containing element. If an <code>XTemplate</code> is used, the component's <i>render data</i>
   * serves as the context.
   * @see ext.Component#renderData render data
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.Labelable.html#cfg-beforeBodyEl Original Ext JS documentation of 'beforeBodyEl'
   */
  public native function get beforeBodyEl():*;

  [ExtConfig]
  /**
   * @private
   */
  public native function set beforeBodyEl(value:*):void;

  [ExtConfig]
  /**
   * An optional string or <code>XTemplate</code> configuration to insert in the field markup
   * before the label text. If an <code>XTemplate</code> is used, the component's <i>render data</i>
   * serves as the context.
   * @see ext.Component#renderData render data
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.Labelable.html#cfg-beforeLabelTextTpl Original Ext JS documentation of 'beforeLabelTextTpl'
   */
  public native function get beforeLabelTextTpl():*;

  [ExtConfig]
  /**
   * @private
   */
  public native function set beforeLabelTextTpl(value:*):void;

  [ExtConfig]
  /**
   * An optional string or <code>XTemplate</code> configuration to insert in the field markup
   * before the label element. If an <code>XTemplate</code> is used, the component's <i>render data</i>
   * serves as the context.
   * @see ext.Component#renderData render data
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.Labelable.html#cfg-beforeLabelTpl Original Ext JS documentation of 'beforeLabelTpl'
   */
  public native function get beforeLabelTpl():*;

  [ExtConfig]
  /**
   * @private
   */
  public native function set beforeLabelTpl(value:*):void;

  [ExtConfig]
  /**
   * An optional string or <code>XTemplate</code> configuration to insert in the field markup
   * before the <i>subTpl markup</i>. If an <code>XTemplate</code> is used, the
   * component's <i>render data</i> serves as the context.
   * @see #getSubTplMarkup() subTpl markup
   * @see ext.Component#renderData render data
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.Labelable.html#cfg-beforeSubTpl Original Ext JS documentation of 'beforeSubTpl'
   */
  public native function get beforeSubTpl():*;

  [ExtConfig]
  /**
   * @private
   */
  public native function set beforeSubTpl(value:*):void;

  /**
   * @inheritDoc
   */
  public native function get bodyEl():ext.dom.Element;

  /**
   * @inheritDoc
   */
  public native function set bodyEl(value:ext.dom.Element):void;

  [ExtConfig]
  /**
   * Defines a timeout in milliseconds for buffering <code>checkChangeEvents</code> that fire in rapid succession.
   * Defaults to 50 milliseconds.
   * @default 50
   * @see #checkChangeEvents
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html#cfg-checkChangeBuffer Original Ext JS documentation of 'checkChangeBuffer'
   */
  public native function get checkChangeBuffer():Number;

  [ExtConfig]
  /**
   * @private
   */
  public native function set checkChangeBuffer(value:Number):void;

  [ArrayElementType("String")]
  [ExtConfig]
  /**
   * A list of event names that will be listened for on the field's <i>input element</i>, which will cause
   * the field's value to be checked for changes. If a change is detected, the <i>change event</i> will be
   * fired, followed by validation if the <code>validateOnChange</code> option is enabled.
   * <p>Defaults to ['change', 'propertychange', 'keyup'] in Internet Explorer, and ['change', 'input', 'textInput', 'keyup',
   * 'dragdrop'] in other browsers. This catches all the ways that field values can be changed in most supported
   * browsers; the only known exceptions at the time of writing are:</p>
   * <ul>
   * <li>Safari 3.2 and older: cut/paste in textareas via the context menu, and dragging text into textareas</li>
   * <li>Opera 10 and 11: dragging text into text fields and textareas, and cut via the context menu in text fields
   * and textareas</li>
   * <li>Opera 9: Same as Opera 10 and 11, plus paste from context menu in text fields and textareas</li>
   * </ul>
   * <p>If you need to guarantee on-the-fly change notifications including these edge cases, you can call the
   * <code>checkChange()</code> method on a repeating interval, e.g. using <code>Ext.TaskManager</code>, or if the field is within
   * a <code>ext.form.FormPanel</code>, you can use the FormPanel's <code>ext.form.FormPanel#pollForChanges</code> configuration to set up
   * such a task automatically.</p>
   * @default Ext.isIE && (!document.documentMode || document.documentMode <= 9) ? [
   *     'change',
   *     'propertychange',
   *     'keyup'
   * ] : [
   *     'change',
   *     'input',
   *     'textInput',
   *     'keyup',
   *     'dragdrop'
   * ]
   * @see #inputEl input element
   * @see #event:onChange change event
   * @see #validateOnChange
   * @see #checkChange()
   * @see ext.util.STaskManager
   * @see ext.form.FormPanel
   * @see ext.form.FormPanel#pollForChanges
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html#cfg-checkChangeEvents Original Ext JS documentation of 'checkChangeEvents'
   */
  public native function get checkChangeEvents():Array;

  [ExtConfig]
  /**
   * @private
   */
  public native function set checkChangeEvents(value:Array):void;

  [ExtConfig]
  /**
   * The CSS class to use when the field value <i>is dirty</i>.
   * @default Ext.baseCSSPrefix + 'form-dirty'
   * @see #isDirty() is dirty
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html#cfg-dirtyCls Original Ext JS documentation of 'dirtyCls'
   */
  public native function get dirtyCls():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set dirtyCls(value:String):void;

  [ExtConfig]
  /**
   * True to disable the field. Disabled Fields will not be <code>submitted</code>.
   * @default false
   * @see ext.form.BasicForm#submit()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Field.html#cfg-disabled Original Ext JS documentation of 'disabled'
   * @see #setDisabled()
   */
  override public native function get disabled():Boolean;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  override public native function set disabled(value:Boolean):void;

  /**
   * @inheritDoc
   */
  public native function get errorEl():ext.dom.Element;

  /**
   * @inheritDoc
   */
  public native function set errorEl(value:ext.dom.Element):void;

  [ExtConfig]
  /**
   * The CSS class to be applied to the error message element.
   * @default Ext.baseCSSPrefix + 'form-error-msg'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.Labelable.html#cfg-errorMsgCls Original Ext JS documentation of 'errorMsgCls'
   */
  public native function get errorMsgCls():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set errorMsgCls(value:String):void;

  [ExtConfig]
  /**
   * An extra CSS class to be applied to the body content element in addition to <code>baseBodyCls</code>.
   * @default ''
   * @see #baseBodyCls
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.Labelable.html#cfg-fieldBodyCls Original Ext JS documentation of 'fieldBodyCls'
   */
  public native function get fieldBodyCls():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set fieldBodyCls(value:String):void;

  [ExtConfig]
  /**
   * The default CSS class for the field input
   * @default 'x-form-field'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html#cfg-fieldCls Original Ext JS documentation of 'fieldCls'
   */
  public native function get fieldCls():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set fieldCls(value:String):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * The label for the field. It gets appended with the <code>labelSeparator</code>, and its position and sizing is
   * determined by the <code>labelAlign</code> and <code>labelWidth</code> configs.
   * @see #labelSeparator
   * @see #labelAlign
   * @see #labelWidth
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.Labelable.html#cfg-fieldLabel Original Ext JS documentation of 'fieldLabel'
   * @see #getFieldLabel()
   * @see #setFieldLabel()
   */
  public native function get fieldLabel():String;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set fieldLabel(value:String):void;

  [ExtConfig]
  /**
   * Optional CSS style(s) to be applied to the <i>field input element</i>. Should be a valid argument to
   * <code>ext.dom.Element#applyStyles()</code>. Defaults to undefined. See also the <code>setFieldStyle()</code> method for changing
   * the style after initialization.
   * @see #inputEl field input element
   * @see ext.dom.Element#applyStyles()
   * @see #setFieldStyle()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html#cfg-fieldStyle Original Ext JS documentation of 'fieldStyle'
   */
  public native function get fieldStyle():String;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set fieldStyle(value:String):void;

  [ExtConfig]
  /**
   * The CSS class to use when the field receives focus
   * @default 'x-form-focus'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html#cfg-focusCls Original Ext JS documentation of 'focusCls'
   */
  override public native function get focusCls():String;

  [ExtConfig]
  /**
   * @private
   */
  override public native function set focusCls(value:String):void;

  [ExtConfig]
  /**
   * A CSS class to be applied to the outermost element to denote that it is participating in the form field layout.
   * @default Ext.baseCSSPrefix + 'form-item'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.Labelable.html#cfg-formItemCls Original Ext JS documentation of 'formItemCls'
   */
  public native function get formItemCls():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set formItemCls(value:String):void;

  [ExtConfig]
  /**
   * Helpful text describing acceptable format for field values.
   * This text will be announced by Assistive Technologies such as screen readers when
   * the field is focused.
   * <p>This option is superseded by <code>ariaHelp</code>.</p>
   * @see #ariaHelp
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html#cfg-formatText Original Ext JS documentation of 'formatText'
   */
  public native function get formatText():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set formatText(value:String):void;

  [ExtConfig]
  /**
   * When set to true, the label element (<code>fieldLabel</code> and <code>labelSeparator</code>) will be automatically
   * hidden if the <code>fieldLabel</code> is empty. Setting this to false will cause the empty label element to be
   * rendered and space to be reserved for it; this is useful if you want a field without a label to line up with
   * other labeled fields in the same form.
   * <p>If you wish to unconditionall hide the label even if a non-empty fieldLabel is configured, then set the
   * <code>hideLabel</code> config to true.</p>
   * @default true
   * @see #fieldLabel
   * @see #labelSeparator
   * @see #hideLabel
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.Labelable.html#cfg-hideEmptyLabel Original Ext JS documentation of 'hideEmptyLabel'
   */
  public native function get hideEmptyLabel():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set hideEmptyLabel(value:Boolean):void;

  [ExtConfig]
  /**
   * Set to true to completely hide the label element (<code>fieldLabel</code> and <code>labelSeparator</code>). Also see
   * <code>hideEmptyLabel</code>, which controls whether space will be reserved for an empty fieldLabel.
   * @default false
   * @see #fieldLabel
   * @see #labelSeparator
   * @see #hideEmptyLabel
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.Labelable.html#cfg-hideLabel Original Ext JS documentation of 'hideLabel'
   */
  public native function get hideLabel():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set hideLabel(value:Boolean):void;

  [ExtConfig]
  /**
   * An optional string or <code>XTemplate</code> configuration to insert in the field markup
   * inside the input element (as attributes). If an <code>XTemplate</code> is used, the component's
   * <i>subTpl data</i> serves as the context.
   * @see #getSubTplData() subTpl data
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html#cfg-inputAttrTpl Original Ext JS documentation of 'inputAttrTpl'
   */
  public native function get inputAttrTpl():*;

  [ExtConfig]
  /**
   * @private
   */
  public native function set inputAttrTpl(value:*):void;

  /**
   * The input Element for this Field. Only available after the field has been rendered.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html#property-inputEl Original Ext JS documentation of 'inputEl'
   */
  public native function get inputEl():ext.dom.Element;

  /**
   * @private
   */
  public native function set inputEl(value:ext.dom.Element):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * The id that will be given to the generated input DOM element. Defaults to an automatically generated id. If you
   * configure this manually, you must make sure it is unique in the document.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html#cfg-inputId Original Ext JS documentation of 'inputId'
   * @see #getInputId()
   */
  public native function get inputId():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set inputId(value:String):void;

  [ExtConfig]
  /**
   * The type attribute for input fields -- e.g. radio, text, password, file. The extended types
   * supported by HTML5 inputs (url, email, etc.) may also be used, though using them will cause older browsers to
   * fall back to 'text'.
   * <p>The type 'password' must be used to render that field type currently -- there is no separate Ext component for
   * that. You can use <code>ext.form.field.FileUploadField</code> which creates a custom-rendered file upload field, but if you want
   * a plain unstyled file input you can use a Base with inputType:'file'.</p>
   * @default 'text'
   * @see ext.form.field.FileUploadField
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html#cfg-inputType Original Ext JS documentation of 'inputType'
   */
  public native function get inputType():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set inputType(value:String):void;

  [ExtConfig]
  /**
   * The CSS class to use when marking the component invalid.
   * @default Ext.baseCSSPrefix + 'form-invalid'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.Labelable.html#cfg-invalidCls Original Ext JS documentation of 'invalidCls'
   */
  public native function get invalidCls():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set invalidCls(value:String):void;

  [ExtConfig]
  /**
   * The error text to use when marking a field invalid and no message is provided
   * @default 'The value in this field is invalid'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html#cfg-invalidText Original Ext JS documentation of 'invalidText'
   */
  public native function get invalidText():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set invalidText(value:String):void;

  /**
   * @inheritDoc
   */
  public native function get isFieldLabelable():Boolean;

  /**
   * @inheritDoc
   */
  public native function set isFieldLabelable(value:Boolean):void;

  /**
   * @inheritDoc
   */
  public native function get isFormField():Boolean;

  /**
   * @inheritDoc
   */
  public native function set isFormField(value:Boolean):void;

  [ExtConfig]
  /**
   * Controls the position and alignment of the <code>fieldLabel</code>. Valid values are:
   * <ul>
   * <li>"left" (the default) - The label is positioned to the left of the field, with its text aligned to the left.
   * Its width is determined by the <code>labelWidth</code> config.</li>
   * <li>"top" - The label is positioned above the field.</li>
   * <li>"right" - The label is positioned to the left of the field, with its text aligned to the right.
   * Its width is determined by the <code>labelWidth</code> config.</li>
   * </ul>
   * @default 'left'
   * @see #fieldLabel
   * @see #labelWidth
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.Labelable.html#cfg-labelAlign Original Ext JS documentation of 'labelAlign'
   */
  public native function get labelAlign():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set labelAlign(value:String):void;

  [ExtConfig]
  /**
   * An optional string or <code>XTemplate</code> configuration to insert in the field markup
   * inside the label element (as attributes). If an <code>XTemplate</code> is used, the component's
   * <i>render data</i> serves as the context.
   * @see ext.Component#renderData render data
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.Labelable.html#cfg-labelAttrTpl Original Ext JS documentation of 'labelAttrTpl'
   */
  public native function get labelAttrTpl():*;

  [ExtConfig]
  /**
   * @private
   */
  public native function set labelAttrTpl(value:*):void;

  [ExtConfig]
  /**
   * The CSS class to be applied to the label element. This (single) CSS class is used to formulate the renderSelector
   * and drives the field layout where it is concatenated with a hyphen ('-') and <code>labelAlign</code>. To add
   * additional classes, use <code>labelClsExtra</code>.
   * @default Ext.baseCSSPrefix + 'form-item-label'
   * @see #labelAlign
   * @see #labelClsExtra
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.Labelable.html#cfg-labelCls Original Ext JS documentation of 'labelCls'
   */
  public native function get labelCls():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set labelCls(value:String):void;

  [ExtConfig]
  /**
   * An optional string of one or more additional CSS classes to add to the label element. Defaults to empty.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.Labelable.html#cfg-labelClsExtra Original Ext JS documentation of 'labelClsExtra'
   */
  public native function get labelClsExtra():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set labelClsExtra(value:String):void;

  /**
   * @inheritDoc
   */
  public native function get labelEl():ext.dom.Element;

  /**
   * @inheritDoc
   */
  public native function set labelEl(value:ext.dom.Element):void;

  [ExtConfig]
  /**
   * The amount of space in pixels between the <code>fieldLabel</code> and the field body.
   * This defaults to <code>5</code> for compatibility with Ext JS 4, however, as of Ext JS 5
   * the space between the label and the body can optionally be determined by the theme
   * using the <code>style:$form-label-horizontal-spacing</code> (for side-aligned labels) and
   * <code>style:$form-label-vertical-spacing</code> (for top-aligned labels) SASS variables.
   * In order for the stylesheet values as to take effect, you must use a labelPad value
   * of <code>null</code>.
   * @default 5
   * @see #fieldLabel
   * @see #style:$form-label-horizontal-spacing
   * @see #style:$form-label-vertical-spacing
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.Labelable.html#cfg-labelPad Original Ext JS documentation of 'labelPad'
   */
  public native function get labelPad():Number;

  [ExtConfig]
  /**
   * @private
   */
  public native function set labelPad(value:Number):void;

  [ExtConfig]
  /**
   * Character(s) to be inserted at the end of the <i>label text</i>.
   * <p>Set to empty string to hide the separator completely.</p>
   * @default ':'
   * @see #fieldLabel label text
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.Labelable.html#cfg-labelSeparator Original Ext JS documentation of 'labelSeparator'
   */
  public native function get labelSeparator():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set labelSeparator(value:String):void;

  [ExtConfig]
  /**
   * A CSS style specification string to apply directly to this field's label.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.Labelable.html#cfg-labelStyle Original Ext JS documentation of 'labelStyle'
   */
  public native function get labelStyle():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set labelStyle(value:String):void;

  [ExtConfig]
  /**
   * The width of the <code>fieldLabel</code> in pixels. Only applicable if <code>labelAlign</code>
   * is set to "left" or "right".
   * @default 100
   * @see #fieldLabel
   * @see #labelAlign
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.Labelable.html#cfg-labelWidth Original Ext JS documentation of 'labelWidth'
   */
  public native function get labelWidth():Number;

  [ExtConfig]
  /**
   * @private
   */
  public native function set labelWidth(value:Number):void;

  [ExtConfig]
  /**
   * The location where the error message text should display. Must be one of the following values:
   * <ul>
   * <li>
   * <p><code>qtip</code> Display a quick tip containing the message when the user hovers over the field.
   * This is the default.</p>
   * <p><b><code>ext.tip.SQuickTipManager#init()</code> must have been called for this setting to work.</b></p>
   * </li>
   * <li>
   * <p><code>title</code> Display the message in a default browser title attribute popup.</p>
   * </li>
   * <li>
   * <p><code>under</code> Add a block div beneath the field containing the error message.</p>
   * </li>
   * <li>
   * <p><code>side</code> Add an error icon to the right of the field, displaying the message in a popup on hover.</p>
   * </li>
   * <li>
   * <p><code>none</code> Don't display any error message. This might be useful if you are implementing custom error display.</p>
   * </li>
   * <li>
   * <p><code>[element id]</code> Add the error message directly to the innerHTML of the specified element.</p>
   * </li>
   * </ul>
   * @default 'qtip'
   * @see ext.tip.SQuickTipManager#init()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.Labelable.html#cfg-msgTarget Original Ext JS documentation of 'msgTarget'
   */
  public native function get msgTarget():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set msgTarget(value:String):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * The name of the field. By default this is used as the parameter name when including the
   * <i>field value</i> in a <i>form submit()</i>. To prevent the field from
   * being included in the form submit, set <code>submitValue</code> to false.
   * @see #getSubmitData() field value
   * @see ext.form.BasicForm#submit() form submit()
   * @see #submitValue
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Field.html#cfg-name Original Ext JS documentation of 'name'
   * @see #getName()
   */
  public native function get name():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set name(value:String):void;

  /**
   * @inheritDoc
   */
  public native function get originalValue():*;

  /**
   * @inheritDoc
   */
  public native function set originalValue(value:*):void;

  [ExtConfig]
  /**
   * true to disable displaying any <i>error message</i> set on this object.
   * @default false
   * @see #setActiveError() error message
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.Labelable.html#cfg-preventMark Original Ext JS documentation of 'preventMark'
   */
  public native function get preventMark():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set preventMark(value:Boolean):void;

  [ExtConfig]
  /**
   * true to mark the field as readOnly in HTML.
   * @default false
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html#cfg-readOnly Original Ext JS documentation of 'readOnly'
   * @see #setReadOnly()
   */
  public native function get readOnly():Boolean;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set readOnly(value:Boolean):void;

  [ExtConfig]
  /**
   * The CSS class applied to the component's main element when it is <code>readOnly</code>.
   * @default Ext.baseCSSPrefix + 'form-readonly'
   * @see #readOnly
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html#cfg-readOnlyCls Original Ext JS documentation of 'readOnlyCls'
   */
  public native function get readOnlyCls():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set readOnlyCls(value:String):void;

  [ExtConfig]
  /**
   * Setting this to false will prevent the field from being <code>submitted</code> even when it is
   * not disabled.
   * @default true
   * @see ext.form.BasicForm#submit()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Field.html#cfg-submitValue Original Ext JS documentation of 'submitValue'
   */
  public native function get submitValue():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set submitValue(value:Boolean):void;

  [ExtConfig]
  /**
   * Sets a DOM tabIndex for this field. tabIndex may be set to <code>-1</code> in order to remove
   * the field from the tab rotation.
   * <p><b>Note:</b> tabIndex only applies to fields that are rendered. It does not effect
   * fields built via applyTo</p>
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html#cfg-tabIndex Original Ext JS documentation of 'tabIndex'
   * @see #getTabIndex()
   * @see #setTabIndex()
   */
  override public native function get tabIndex():Number;

  [ExtConfig]
  /**
   * @private
   */
  override public native function set tabIndex(value:Number):void;

  [ExtConfig]
  /**
   * Whether the field should validate when it loses focus. This will cause fields to be validated
   * as the user steps through the fields in the form regardless of whether they are making changes to those fields
   * along the way. See also <code>validateOnChange</code>.
   * @default true
   * @see #validateOnChange
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html#cfg-validateOnBlur Original Ext JS documentation of 'validateOnBlur'
   */
  public native function get validateOnBlur():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set validateOnBlur(value:Boolean):void;

  [ExtConfig]
  /**
   * Specifies whether this field should be validated immediately whenever a change in its value is detected.
   * If the validation results in a change in the field's validity, a <code>event:onValidityChange</code> event will be
   * fired. This allows the field to show feedback about the validity of its contents immediately as the user is
   * typing.
   * <p>When set to false, feedback will not be immediate. However the form will still be validated before submitting if
   * the clientValidation option to <code>ext.form.BasicForm#doAction()</code> is enabled, or if the field or form are validated
   * manually.</p>
   * <p>See also <code>ext.form.field.BaseField#checkChangeEvents</code> for controlling how changes to the field's value are
   * detected.</p>
   * @default true
   * @see #event:onValidityChange
   * @see ext.form.BasicForm#doAction()
   * @see ext.form.field.BaseField#checkChangeEvents
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Field.html#cfg-validateOnChange Original Ext JS documentation of 'validateOnChange'
   */
  public native function get validateOnChange():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set validateOnChange(value:Boolean):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * This property, when a <code>String</code>, contributes its value to the error state of this
   * instance as reported by <code>getErrors</code>.
   * @see String
   * @see #getErrors()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Field.html#cfg-validation Original Ext JS documentation of 'validation'
   * @see #getValidation()
   * @see #setValidation()
   */
  public native function get validation():*;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set validation(value:*):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * A value to initialize this field with.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Field.html#cfg-value Original Ext JS documentation of 'value'
   * @see #getValue()
   * @see #setValue()
   */
  public native function get value():Object;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set value(value:Object):void;

  [ExtConfig]
  /**
   * The event name(s) to use to publish the <code>value</code>
   * <code>ext.form.field.BaseField#bind</code> for this field.
   * @default 'change'
   * @since 5.0.1
   * @see #value
   * @see ext.form.field.BaseField#bind
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Field.html#cfg-valuePublishEvent Original Ext JS documentation of 'valuePublishEvent'
   */
  public native function get valuePublishEvent():*;

  [ExtConfig]
  /**
   * @private
   */
  public native function set valuePublishEvent(value:*):void;

  /**
   * @inheritDoc
   */
  public native function batchChanges(fn:Function):void;

  /**
   * Template method before a field is reset.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Field.html#method-beforeReset Original Ext JS documentation of 'beforeReset'
   */
  protected native function beforeReset():void;

  /**
   * @inheritDoc
   */
  public native function checkChange():void;

  /**
   * @inheritDoc
   */
  public native function checkDirty():void;

  /**
   * @inheritDoc
   */
  public native function cleanupField():void;

  /**
   * Clear any invalid styles/messages for this field.
   * <p><b>Note</b>: this method does not cause the Field's <code>validate()</code> or <code>isValid()</code> methods to return <code>true</code>
   * if the value does not <i>pass</i> validation. So simply clearing a field's errors will not necessarily allow
   * submission of forms submitted with the <code>ext.form.action.SubmitAction#clientValidation</code> option set.</p>
   * @see #validate()
   * @see #isValid()
   * @see ext.form.action.SubmitAction#clientValidation
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html#method-clearInvalid Original Ext JS documentation of 'clearInvalid'
   */
  public native function clearInvalid():void;

  /**
   * Called when focus leaves this input field.
   * Used to postprocess raw values and perform conversion and validation.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html#method-completeEdit Original Ext JS documentation of 'completeEdit'
   */
  protected native function completeEdit():void;

  /**
   * @inheritDoc
   */
  public native function extractFileInput():js.HTMLElement;

  /**
   * @inheritDoc
   */
  public native function getActiveError():String;

  /**
   * @inheritDoc
   */
  public native function getActiveErrors():Array;

  /**
   * @inheritDoc
   */
  public native function getErrors(value:*):Array;

  /**
   * @inheritDoc
   */
  public native function getFieldLabel():String;

  /**
   * Returns the input id for this field. If none was specified via the <code>inputId</code> config, then an id will be
   * automatically generated.
   * @see #inputId
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html#method-getInputId Original Ext JS documentation of 'getInputId'
   */
  public native function getInputId():String;

  /**
   * Generates the arguments for the field decorations <i>rendering template</i>.
   * @param data optional object to use as the base data object. If provided,
   * this method will add properties to the base object instead of creating a new one.
   * @return The template arguments
   * @see #labelableRenderTpl rendering template
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.Labelable.html#method-getLabelableRenderData Original Ext JS documentation of 'getLabelableRenderData'
   */
  protected native function getLabelableRenderData(data:Object):Object;

  /**
   * @inheritDoc
   */
  public native function getModelData(includeEmptyText:Boolean):Object;

  /**
   * @inheritDoc
   */
  public native function getName():String;

  /**
   * Returns the raw value of the field, without performing any normalization, conversion, or validation. To get a
   * normalized and converted value see <code>getValue()</code>.
   * @return value The raw String value of the field
   * @see #getValue()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html#method-getRawValue Original Ext JS documentation of 'getRawValue'
   */
  public native function getRawValue():String;

  /**
   * Creates and returns the data object to be used when rendering the <code>fieldSubTpl</code>.
   * @return The template data
   * @see #fieldSubTpl
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html#method-getSubTplData Original Ext JS documentation of 'getSubTplData'
   */
  public native function getSubTplData(fieldData:*):Object;

  /**
   * Gets the markup to be inserted into the outer template's bodyEl. Defaults to empty string, should be implemented
   * by classes including this mixin as needed.
   * @return The markup to be inserted
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.Labelable.html#method-getSubTplMarkup Original Ext JS documentation of 'getSubTplMarkup'
   */
  protected native function getSubTplMarkup(fieldData:Object):String;

  /**
   * @inheritDoc
   */
  public native function getSubmitData():Object;

  /**
   * Returns the value that would be included in a standard form submit for this field. This will be combined with the
   * field's name to form a name=value pair in the <i>submitted parameters</i>. If an empty string is
   * returned then just the name= will be submitted; if null is returned then nothing will be submitted.
   * <p>Note that the value returned will have been <code>processed</code> but may or may not have been
   * successfully <code>validated</code>.</p>
   * @return The value to be submitted, or null.
   * @see #getSubmitData() submitted parameters
   * @see #processRawValue()
   * @see #validate()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html#method-getSubmitValue Original Ext JS documentation of 'getSubmitValue'
   */
  public native function getSubmitValue():String;

  /**
   * Returns the value of <code>validation</code>.
   * @see #validation
   */
  public native function getValidation():*;

  /**
   * Returns the current data value of the field. The type of value returned is particular to the type of the
   * particular field (e.g. a Date object for <code>ext.form.field.DateField</code>), as the result of calling <code>rawToValue()</code> on
   * the field's <code>processed</code> String value. To return the raw String value, see <code>getRawValue()</code>.
   * @return value The field value
   * @see ext.form.field.DateField
   * @see #rawToValue()
   * @see #processRawValue()
   * @see #getRawValue()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html#method-getValue Original Ext JS documentation of 'getValue'
   */
  public native function getValue():*;

  /**
   * @inheritDoc
   */
  public native function hasActiveError():Boolean;

  /**
   * @inheritDoc
   */
  public native function hasVisibleLabel():Boolean;

  /**
   * @inheritDoc
   */
  public native function initField():void;

  /**
   * @inheritDoc
   */
  public native function initLabelable():void;

  /**
   * @inheritDoc
   */
  public native function initValue():void;

  /**
   * @inheritDoc
   */
  public native function isDirty():Boolean;

  /**
   * @inheritDoc
   */
  public native function isEqual(value1:Object, value2:Object):Boolean;

  /**
   * @inheritDoc
   */
  public native function isFileUpload():Boolean;

  /**
   * Returns whether or not the field value is currently valid by <code>validating</code> the
   * <i>processed raw value</i> of the field. <b>Note</b>: <code>disabled</code> fields are
   * always treated as valid.
   * @return True if the value is valid, else false
   * @see #getErrors()
   * @see #processRawValue() processed raw value
   * @see #disabled
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html#method-isValid Original Ext JS documentation of 'isValid'
   */
  public native function isValid():Boolean;

  /**
   * Display one or more error messages associated with this field, using
   * <code>ext.form.Labelable#msgTarget</code> to determine how to display the messages and
   * applying <code>ext.form.Labelable#invalidCls</code> to the field's UI element.
   * <pre>
   * var formPanel = Ext.create('Ext.form.Panel', {
   *     title: 'Contact Info',
   *     width: 300,
   *     bodyPadding: 10,
   *     renderTo: Ext.getBody(),
   *     items: [{
   *         xtype: 'textfield',
   *         name: 'name',
   *         id: 'nameId',
   *         fieldLabel: 'Name'
   *     }],
   *     bbar: [{
   *         text: 'Mark both fields invalid',
   *         handler: function() {
   *             var nameField = formPanel.getForm().findField('name');
   *             nameField.markInvalid('Name invalid message');
   *
   *             // multiple error string syntax
   *             // nameField.markInvalid(['First message', 'Second message']);
   *         }
   *     }]
   * });
   * </pre>
   * <p><b>Note</b>: this method does not cause the Field's <code>validate()</code> or
   * <code>isValid()</code> methods to return <code>false</code> if the value does <i>pass</i> validation.
   * So simply marking a Field as invalid will not prevent submission of forms
   * submitted with the <code>ext.form.action.SubmitAction#clientValidation</code> option set.</p>
   * @param errors The validation message(s) to display.
   * @see ext.form.Labelable#msgTarget
   * @see ext.form.Labelable#invalidCls
   * @see #validate()
   * @see #isValid()
   * @see ext.form.action.SubmitAction#clientValidation
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html#method-markInvalid Original Ext JS documentation of 'markInvalid'
   */
  public native function markInvalid(errors:*):void;

  /**
   * Performs any necessary manipulation of a raw field value to prepare it for <code>conversion</code> and/or
   * <code>validation</code>, for instance stripping out ignored characters. In the base implementation it does
   * nothing; individual subclasses may override this as needed.
   * @param value The unprocessed string value
   * @return The processed string value
   * @see #rawToValue()
   * @see #validate()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html#method-processRawValue Original Ext JS documentation of 'processRawValue'
   */
  public native function processRawValue(value:Object):Object;

  /**
   * Converts a raw input field value into a mixed-type value that is suitable for this particular field type. This
   * allows controlling the normalization and conversion of user-entered values into field-type-appropriate values,
   * e.g. a Date object for <code>ext.form.field.DateField</code>, and is invoked by <code>getValue()</code>.
   * <p>It is up to individual implementations to decide how to handle raw values that cannot be successfully converted
   * to the desired object type.</p>
   * <p>See <code>valueToRaw()</code> for the opposite conversion.</p>
   * <p>The base implementation does no conversion, returning the raw value untouched.</p>
   * @return The converted value.
   * @see ext.form.field.DateField
   * @see #getValue()
   * @see #valueToRaw()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html#method-rawToValue Original Ext JS documentation of 'rawToValue'
   */
  public native function rawToValue(rawValue:Object):Object;

  /**
   * @inheritDoc
   */
  public native function reset():void;

  /**
   * @inheritDoc
   */
  public native function resetOriginalValue():void;

  /**
   * @inheritDoc
   */
  public native function setActiveError(msg:String):void;

  /**
   * @inheritDoc
   */
  public native function setActiveErrors(errors:Array):void;

  /**
   * @inheritDoc
   */
  public native function setFieldDefaults(defaults:Object):void;

  /**
   * @inheritDoc
   */
  public native function setFieldLabel(label:String):void;

  /**
   * Set the <i>CSS style</i> of the <i>field input element</i>.
   * @param style The style(s) to apply. Should be a valid argument to <code>ext.dom.Element#applyStyles()</code>.
   * @see #fieldStyle CSS style
   * @see #inputEl field input element
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html#method-setFieldStyle Original Ext JS documentation of 'setFieldStyle'
   * @see ext.dom.Element#applyStyles()
   */
  public native function setFieldStyle(style:*):void;

  /**
   * Sets the field's raw value directly, bypassing <i>value conversion</i>, change detection, and
   * validation. To set the value with these additional inspections see <code>setValue()</code>.
   * @param value The value to set
   * @return value The field value that is set
   * @see #valueToRaw() value conversion
   * @see #setValue()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html#method-setRawValue Original Ext JS documentation of 'setRawValue'
   */
  public native function setRawValue(value:Object):Object;

  /**
   * Sets the read only state of this field.
   * @param readOnly Whether the field should be read only.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html#method-setReadOnly Original Ext JS documentation of 'setReadOnly'
   */
  public native function setReadOnly(readOnly:Boolean):void;

  /**
   * Sets the value of <code>validation</code>.
   * @param validation The new value.
   * @see #validation
   */
  public native function setValidation(validation:*):void;

  /**
   * Sets a data value into the field and runs the change detection and validation. To set the value directly
   * without these inspections see <code>setRawValue()</code>.
   * @param value The value to set
   * @return this
   * @see #setRawValue()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html#method-setValue Original Ext JS documentation of 'setValue'
   */
  public native function setValue(value:*):ext.form.field.IField;

  /**
   * Transform the raw value before it is set
   * @param value The value
   * @return The value to set
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html#method-transformRawValue Original Ext JS documentation of 'transformRawValue'
   */
  protected native function transformRawValue(value:Object):Object;

  /**
   * @inheritDoc
   */
  public native function trimLabelSeparator():String;

  /**
   * @inheritDoc
   */
  public native function unsetActiveError():void;

  /**
   * @inheritDoc
   */
  public native function validate():Boolean;

  /**
   * Uses <code>getErrors()</code> to build an array of validation errors. If any errors are found, they are passed to
   * <code>markInvalid()</code> and false is returned, otherwise true is returned.
   * <p>Previously, subclasses were invited to provide an implementation of this to process validations - from 3.2
   * onwards <code>getErrors()</code> should be overridden instead.</p>
   * @param value The value to validate
   * @return True if all validations passed, false if one or more failed
   * @see #getErrors()
   * @see #markInvalid()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html#method-validateValue Original Ext JS documentation of 'validateValue'
   */
  public native function validateValue(value:Object):Boolean;

  /**
   * Converts a mixed-type value to a raw representation suitable for displaying in the field. This allows controlling
   * how value objects passed to <code>setValue()</code> are shown to the user, including localization. For instance, for a
   * <code>ext.form.field.DateField</code>, this would control how a Date object passed to <code>setValue()</code> would be converted
   * to a String for display in the field.
   * <p>See <code>rawToValue()</code> for the opposite conversion.</p>
   * <p>The base implementation simply does a standard toString conversion, and converts <i>empty values</i>
   * to an empty string.</p>
   * @param value The mixed-type value to convert to the raw representation.
   * @return The converted raw value.
   * @see #setValue()
   * @see ext.form.field.DateField
   * @see #rawToValue()
   * @see ext.SExt#isEmpty() empty values
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.form.field.Base.html#method-valueToRaw Original Ext JS documentation of 'valueToRaw'
   */
  public native function valueToRaw(value:Object):Object;
}
}