package ext.grid.column {

[Uses("ext.grid.column.Column")]
[Uses("ext.grid.header.HeaderContainer")]
[Uses("ext.util.FocusableContainer")]
[Uses("ext.Mixin")]
[Uses("ext.Base")]
[Uses("ext.container.Container")]
[Uses("ext.mixin.Queryable")]
[Uses("ext.Component")]
[Uses("ext.util.Animate")]
[Uses("ext.util.ElementContainer")]
[Uses("ext.util.Focusable")]
[Uses("ext.mixin.ComponentDelegation")]
[Uses("ext.mixin.Inheritable")]
[Uses("ext.util.Positionable")]
[Uses("ext.mixin.Bindable")]
[Uses("ext.mixin.Keyboard")]
[Uses("ext.mixin.Observable")]
[Uses("ext.mixin.Identifiable")]
[Uses("ext.state.Stateful")]
[Uses("ext.mixin.Accessible")]
[Uses("ext.util.Renderable")]
[Uses("ext.util.Floating")]
[Uses("ext.mixin.Container")]
[Native("Ext.grid.column.RowNumberer", require)]
/**
 * A special type of Grid <code>ext.grid.column.Column</code> that provides automatic
 * row numbering.
 * <p>Usage:</p>
 * <pre>
 * columns: [
 *     {xtype: 'rownumberer'},
 *     {text: "Company", flex: 1, sortable: true, dataIndex: 'company'},
 *     {text: "Price", width: 120, sortable: true, renderer: Ext.util.Format.usMoney, dataIndex: 'price'},
 *     {text: "Change", width: 120, sortable: true, dataIndex: 'change'},
 *     {text: "% Change", width: 120, sortable: true, dataIndex: 'pctChange'},
 *     {text: "Last Updated", width: 120, sortable: true, renderer: Ext.util.Format.dateRenderer('m/d/Y'), dataIndex: 'lastChange'}
 * ]
 * </pre>
 * @see ext.grid.column.Column
 * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.RowNumberer.html Original Ext JS documentation of 'Ext.grid.column.RowNumberer'
 */
public class RowNumberer extends ext.grid.column.Column {
  /**
   * @param config @inheritDoc
   */
  public function RowNumberer(config:ext.grid.column.RowNumberer = null) {
    super();
  }

  [ExtConfig]
  /**
   * False to disable drag-drop reordering of this column.
   * @default false
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.RowNumberer.html#cfg-draggable Original Ext JS documentation of 'draggable'
   */
  override public native function get draggable():*;

  [ExtConfig]
  /**
   * @private
   */
  override public native function set draggable(value:*):void;

  /**
   * <code>true</code> in this class to identify an object as an instantiated RowNumberer, or subclass thereof.
   * @default true
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.RowNumberer.html#property-isRowNumberer Original Ext JS documentation of 'isRowNumberer'
   */
  public native function get isRowNumberer():Boolean;

  /**
   * @private
   */
  public native function set isRowNumberer(value:Boolean):void;

  [ExtConfig]
  /**
   * This flag indicates that the renderer produces HTML.
   * <p>If this column is going to be updated rapidly, and the
   * <code>ext.grid.column.Column#renderer</code> or <code>updater</code> only produces
   * text, then to avoid the expense of HTML parsing and element production during the
   * update, this property may be configured as <code>false</code>.</p>
   * @default false
   * @see ext.grid.column.Column#renderer
   * @see #updater
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.RowNumberer.html#cfg-producesHTML Original Ext JS documentation of 'producesHTML'
   */
  override public native function get producesHTML():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  override public native function set producesHTML(value:Boolean):void;

  [ExtConfig]
  /**
   * @default false
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.RowNumberer.html#cfg-sortable Original Ext JS documentation of 'sortable'
   */
  override public native function get sortable():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  override public native function set sortable(value:Boolean):void;

  [ExtConfig]
  /**
   * Any valid text or HTML fragment to display in the header cell for the row number column.
   * @default "&amp;#160;"
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.RowNumberer.html#cfg-text Original Ext JS documentation of 'text'
   * @see #setText()
   */
  override public native function get text():String;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  override public native function set text(value:String):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * The default width in pixels of the row number column.
   * @default 23
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.column.RowNumberer.html#cfg-width Original Ext JS documentation of 'width'
   * @see #getWidth()
   * @see #setWidth()
   */
  override public native function get width():*;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  override public native function set width(value:*):void;
}
}