package ext.grid.feature {

[Uses("ext.grid.feature.Grouping")]
[Uses("ext.grid.feature.AbstractSummary")]
[Uses("ext.grid.feature.Feature")]
[Uses("ext.util.Observable")]
[Uses("ext.mixin.Observable")]
[Uses("ext.Mixin")]
[Uses("ext.Base")]
[Uses("ext.mixin.Identifiable")]
[Native("Ext.grid.feature.GroupingSummary", require)]
/**
 * This feature adds an aggregate summary row at the bottom of each group that is provided
 * by the <code>ext.grid.feature.Grouping</code> feature. There are two aspects to the summary:
 * <p><b><i>Calculation</i></b></p>
 * <p>The summary value needs to be calculated for each column in the grid. This is controlled
 * by the summaryType option specified on the column. There are several built in summary types,
 * which can be specified as a string on the column configuration. These call underlying methods
 * on the store:</p>
 * <ul>
 * <li><code>count</code></li>
 * <li><code>sum</code></li>
 * <li><code>min</code></li>
 * <li><code>max</code></li>
 * <li><code>average</code></li>
 * </ul>
 * <p>Alternatively, the summaryType can be a function definition. If this is the case,
 * the function is called with two parameters: an array of records, and an array of field values
 * to calculate the summary value.</p>
 * <p><b><i>Rendering</i></b></p>
 * <p>Similar to a column, the summary also supports a summaryRenderer function. This
 * summaryRenderer is called before displaying a value. The function is optional, if
 * not specified the default calculated value is shown. The summaryRenderer is called with:</p>
 * <ul>
 * <li>value {Object} - The calculated value.</li>
 * <li>summaryData {Object} - Contains all raw summary values for the row.</li>
 * <li>field {String} - The name of the field we are calculating</li>
 * <li>metaData {Object} - A collection of metadata about the current cell; can be used or modified by the renderer.</li>
 * </ul>
 * <p><b><i>Example Usage</i></b></p>
 * <p><b>Example:</b></p>
 * <pre>
 * Ext.define('TestResult', {
 *     extend: 'Ext.data.Model',
 *     fields: ['student', 'subject', {
 *         name: 'mark',
 *         type: 'int'
 *     }]
 * });
 *
 * Ext.create('Ext.grid.Panel', {
 *     width: 200,
 *     height: 240,
 *     renderTo: document.body,
 *     features: [{
 *         groupHeaderTpl: 'Subject: {name}',
 *         ftype: 'groupingsummary'
 *     }],
 *     store: {
 *         model: 'TestResult',
 *         groupField: 'subject',
 *         data: [{
 *             student: 'Student 1',
 *             subject: 'Math',
 *             mark: 84
 *         },{
 *             student: 'Student 1',
 *             subject: 'Science',
 *             mark: 72
 *         },{
 *             student: 'Student 2',
 *             subject: 'Math',
 *             mark: 96
 *         },{
 *             student: 'Student 2',
 *             subject: 'Science',
 *             mark: 68
 *         }]
 *     },
 *     columns: [{
 *         dataIndex: 'student',
 *         text: 'Name',
 *         summaryType: 'count',
 *         summaryRenderer: function(value){
 *             return Ext.String.format('{0} student{1}', value, value !== 1 ? 's' : '');
 *         }
 *     }, {
 *         dataIndex: 'mark',
 *         text: 'Mark',
 *         summaryType: 'average'
 *     }]
 * });
 * </pre>
 * @see ext.grid.feature.Grouping
 * @see ext.data.Store#count()
 * @see ext.data.Store#sum()
 * @see ext.data.Store#min()
 * @see ext.data.Store#max()
 * @see ext.data.Store#average()
 * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.feature.GroupingSummary.html Original Ext JS documentation of 'Ext.grid.feature.GroupingSummary'
 */
public class GroupingSummary extends ext.grid.feature.Grouping {
  /**
   * @param config @inheritDoc
   */
  public function GroupingSummary(config:ext.grid.feature.GroupingSummary = null) {
    super();
  }
}
}