package ext.grid.plugin.events {
import ext.data.Model;
import js.HTMLElement;
import net.jangaroo.ext.FlExtEvent;

[Uses("net.jangaroo.ext.FlExtEvent")]
public class GridViewDragDropPlugin_node_data_overModel_dropPosition_dropHandlersEvent extends net.jangaroo.ext.FlExtEvent {
  /**
   * <b>This event is fired through the <code>GridView</code> and its owning
   * <code>ext.grid.GridPanel</code>. You can add listeners to the grid or grid <i>view config</i> object</b>
   * <p>Fired when a drop gesture has been triggered by a mouseup event in a valid drop
   * position in the grid view.</p>
   * <p>Returning <code>false</code> to this event signals that the drop gesture was invalid and
   * animates the drag proxy back to the point from which the drag began.</p>
   * <p>The dropHandlers parameter can be used to defer the processing of this event. For
   * example, you can force the handler to wait for the result of a message box
   * confirmation or an asynchronous server call (<i>see the details of the dropHandlers
   * property for more information</i>).</p>
   * <pre>
   * grid.on('beforedrop', function(node, data, overModel, dropPosition, dropHandlers) {
   *     // Defer the handling
   *     dropHandlers.wait = true;
   *     Ext.MessageBox.confirm('Drop', 'Are you sure', function(btn){
   *         if (btn === 'yes') {
   *             dropHandlers.processDrop();
   *         } else {
   *             dropHandlers.cancelDrop();
   *         }
   *     });
   * });
   * </pre>
   * <p>Any other return value continues with the data transfer operation unless the wait
   * property is set.</p>
   * @see ext.view.TableView
   * @see ext.grid.GridPanel
   * @see ext.grid.GridPanel#viewConfig view config
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.grid.plugin.DragDrop.html#event-beforedrop Original Ext JS documentation of 'beforedrop'
   * @see ext.grid.plugin.GridViewDragDropPlugin
   * @eventType onBeforeDrop
   */
  public static const BEFORE_DROP:String = "onBeforeDrop";

  public static const __PARAMETER_SEQUENCE__:Array;

  public function GridViewDragDropPlugin_node_data_overModel_dropPosition_dropHandlersEvent(type:String, arguments:Array) {
    super(null, null);
  }

  /**
   * The data object gathered at mousedown time by the
   * cooperating <code>ext.dd.DragZone</code>'s <code>getDragData</code> method. It contains the following properties:
   * @see ext.dd.DragZone
   * @see ext.dd.DragZone#getDragData()
   */
  public native function get data():Object;

  /**
   * This parameter allows the developer to control when the drop action takes place.
   * It is useful if any asynchronous processing needs to be completed before
   * performing the drop. This object has the following properties:
   */
  public native function get dropHandlers():Object;

  /**
   * <code>"before"</code> or <code>"after"</code> depending on whether the
   * cursor is above or below the mid-line of the node.
   */
  public native function get dropPosition():String;

  /**
   * The <i>grid view</i> node <b>if any</b> over
   * which the cursor was positioned.
   * @see ext.view.TableView grid view
   */
  public native function get node():js.HTMLElement;

  /**
   * The Model over which the drop gesture took place
   */
  public native function get overModel():ext.data.Model;
}
}