package ext.list {
import ext.Widget;
import ext.data.TreeModel;

[Uses("ext.Widget")]
[Uses("ext.mixin.Inheritable")]
[Uses("ext.Mixin")]
[Uses("ext.Base")]
[Uses("ext.Evented")]
[Uses("ext.mixin.Observable")]
[Uses("ext.mixin.Identifiable")]
[Uses("ext.mixin.Pluggable")]
[Uses("ext.mixin.ComponentDelegation")]
[Uses("ext.mixin.Bindable")]
[Native("Ext.list.Tree", require)]
/**
 * @see ext.list.events.Tree_recordEvent.SELECTION_CHANGE
 * @eventType ext.list.events.Tree_recordEvent.SELECTION_CHANGE
 */
[Event(name = 'onSelectionChange', type = 'ext.list.events.Tree_recordEvent')]
/**
 * A lightweight component to display data in a simple tree structure using a
 * <code>ext.data.TreeStore</code>.
 * <p>Simple Treelist using inline data:</p>
 * <p><b>Example:</b></p>
 * <pre>
 * Ext.create({
 *     xtype: 'treelist',
 *     store: {
 *         root: {
 *         expanded: true,
 *             children: [{
 *                 text: 'detention',
 *                 leaf: true,
 *                 iconCls: 'x-fa fa-frown-o'
 *             }, {
 *                 text: 'homework',
 *                 expanded: true,
 *                 iconCls: 'x-fa fa-folder',
 *                 children: [{
 *                     text: 'book report',
 *                     leaf: true,
 *                     iconCls: 'x-fa fa-book'
 *                 }, {
 *                     text: 'algebra',
 *                     leaf: true,
 *                     iconCls: 'x-fa fa-graduation-cap'
 *                 }]
 *             }, {
 *                 text: 'buy lottery tickets',
 *                 leaf: true,
 *                 iconCls: 'x-fa fa-usd'
 *             }]
 *         }
 *     },
 *     renderTo: Ext.getBody()
 * });
 * </pre>
 * <p>To collapse the Treelist for use in a smaller navigation view see <code>micro</code>.
 * Parent Treelist node expansion may be refined using the <code>singleExpand</code> and
 * <code>expanderOnly</code> config options. Treelist nodes will be selected when clicked /
 * tapped excluding clicks on the expander unless <code>selectOnExpander</code> is set to
 * <code>true</code>.</p>
 * @see ext.data.TreeStore
 * @see #micro
 * @see #singleExpand
 * @see #expanderOnly
 * @see #selectOnExpander
 * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.list.Tree.html Original Ext JS documentation of 'Ext.list.Tree'
 */
public class Tree extends ext.Widget {
  /**
   * @param config @inheritDoc
   */
  public function Tree(config:ext.list.Tree = null) {
    super();
  }

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * The default configuration for the widgets created for tree items.
   * @default {
   *     xtype: 'treelistitem'
   * }
   * <ul>
   * <li><code>xtype</code> : String (optional)
   * The type of item to create. By default, items are <code>ext.list.TreeItem</code>
   * instances. This can be customized but this <code>xtype</code> must reference a class that
   * ultimately derives from the <code>ext.list.AbstractTreeItem</code> base class.
   * @default "treelistitem"
   * </li>
   * </ul>
   * @see ext.list.TreeItem
   * @see ext.list.AbstractTreeItem
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.list.Tree.html#property-xtype Original Ext JS documentation of 'xtype'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.list.Tree.html#cfg-defaults Original Ext JS documentation of 'defaults'
   * @see #getDefaults()
   * @see #setDefaults()
   */
  public native function get defaults():Object;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set defaults(value:Object):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * <code>true</code> to expand only on the click of the expander element. Setting this to
   * <code>false</code> will allow expansion on click of any part of the element.
   * @default true
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.list.Tree.html#cfg-expanderOnly Original Ext JS documentation of 'expanderOnly'
   * @see #getExpanderOnly()
   * @see #setExpanderOnly()
   */
  public native function get expanderOnly():Boolean;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set expanderOnly(value:Boolean):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * Set as <code>true</code> to highlight all items on the path to the currently selected
   * node.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.list.Tree.html#cfg-highlightPath Original Ext JS documentation of 'highlightPath'
   * @see #getHighlightPath()
   * @see #setHighlightPath()
   */
  public native function get highlightPath():Boolean;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set highlightPath(value:Boolean):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * Set to <code>true</code> to collapse the Treelist UI to display only the
   * <code>icons</code> of the root nodes. Hovering
   * the cursor (or tapping on a touch-enabled device) shows the child nodes beside
   * the icon.
   * @default false
   * @see ext.data.NodeInterface#iconCls
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.list.Tree.html#cfg-micro Original Ext JS documentation of 'micro'
   * @see #getMicro()
   * @see #setMicro()
   */
  public native function get micro():Boolean;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set micro(value:Boolean):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * <code>true</code> to select the node when clicking the expander.
   * @default false
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.list.Tree.html#cfg-selectOnExpander Original Ext JS documentation of 'selectOnExpander'
   * @see #getSelectOnExpander()
   * @see #setSelectOnExpander()
   */
  public native function get selectOnExpander():Boolean;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set selectOnExpander(value:Boolean):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * The current selected node.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.list.Tree.html#cfg-selection Original Ext JS documentation of 'selection'
   * @see #getSelection()
   * @see #setSelection()
   */
  public native function get selection():ext.data.TreeModel;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set selection(value:ext.data.TreeModel):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * <code>true</code> if only 1 node per branch may be expanded.
   * @default false
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.list.Tree.html#cfg-singleExpand Original Ext JS documentation of 'singleExpand'
   * @see #getSingleExpand()
   * @see #setSingleExpand()
   */
  public native function get singleExpand():Boolean;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set singleExpand(value:Boolean):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * The data source to which this component is bound.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.list.Tree.html#cfg-store Original Ext JS documentation of 'store'
   * @see #getStore()
   * @see #setStore()
   */
  public native function get store():*;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set store(value:*):void;

  /**
   * Returns the value of <code>defaults</code>.
   * @see #defaults
   */
  public native function getDefaults():Object;

  /**
   * Returns the value of <code>expanderOnly</code>.
   * @see #expanderOnly
   */
  public native function getExpanderOnly():Boolean;

  /**
   * Returns the value of <code>highlightPath</code>.
   * @see #highlightPath
   */
  public native function getHighlightPath():Boolean;

  /**
   * Get a child <code>ext.list.AbstractTreeItem</code> by node.
   * @param node The node.
   * @return The item. <code>null</code> if not found.
   * @see ext.list.AbstractTreeItem
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.list.Tree.html#method-getItem Original Ext JS documentation of 'getItem'
   */
  public native function getItem(node:ext.data.TreeModel):ext.list.AbstractTreeItem;

  /**
   * This method is called to populate and return a config object for new nodes. This
   * can be overridden by derived classes to manipulate properties or <code>xtype</code> of the
   * returned object. Upon return, the object is passed to <code>ext.SExt#create()</code> and the
   * reference is stored as part of this tree.
   * <p>The base class implementation will apply any configured <code>defaults</code> to the
   * object it returns.</p>
   * @param node The node backing the item.
   * @param parent The parent item. This is never <code>null</code> but
   * may be an instance of <code>ext.list.RootTreeItem</code>.
   * @return The config object to pass to <code>ext.SExt#create()</code> for the item.
   * @see ext.SExt#create()
   * @see #defaults
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.list.Tree.html#method-getItemConfig Original Ext JS documentation of 'getItemConfig'
   * @see ext.list.RootTreeItem
   */
  public native function getItemConfig(node:ext.data.TreeModel, parent:ext.list.AbstractTreeItem):Object;

  /**
   * Returns the value of <code>micro</code>.
   * @see #micro
   */
  public native function getMicro():Boolean;

  /**
   * Returns the value of <code>selectOnExpander</code>.
   * @see #selectOnExpander
   */
  public native function getSelectOnExpander():Boolean;

  /**
   * Returns the value of <code>selection</code>.
   * @see #selection
   */
  public native function getSelection():ext.data.TreeModel;

  /**
   * Returns the value of <code>singleExpand</code>.
   * @see #singleExpand
   */
  public native function getSingleExpand():Boolean;

  /**
   * Returns the value of <code>store</code>.
   * @see #store
   */
  public native function getStore():*;

  /**
   * Sets the value of <code>defaults</code>.
   * @param defaults The new value.
   * @see #defaults
   */
  public native function setDefaults(defaults:Object):void;

  /**
   * Sets the value of <code>expanderOnly</code>.
   * @param expanderOnly The new value.
   * @see #expanderOnly
   */
  public native function setExpanderOnly(expanderOnly:Boolean):void;

  /**
   * Sets the value of <code>highlightPath</code>.
   * @param highlightPath The new value.
   * @see #highlightPath
   */
  public native function setHighlightPath(highlightPath:Boolean):void;

  /**
   * Sets the value of <code>micro</code>.
   * @param micro The new value.
   * @see #micro
   */
  public native function setMicro(micro:Boolean):void;

  /**
   * Sets the value of <code>selectOnExpander</code>.
   * @param selectOnExpander The new value.
   * @see #selectOnExpander
   */
  public native function setSelectOnExpander(selectOnExpander:Boolean):void;

  /**
   * Sets the value of <code>selection</code>.
   * @param selection The new value.
   * @see #selection
   */
  public native function setSelection(selection:ext.data.TreeModel):void;

  /**
   * Sets the value of <code>singleExpand</code>.
   * @param singleExpand The new value.
   * @see #singleExpand
   */
  public native function setSingleExpand(singleExpand:Boolean):void;

  /**
   * Sets the value of <code>store</code>.
   * @param store The new value.
   * @see #store
   */
  public native function setStore(store:*):void;
}
}