package ext.menu {

[Uses("ext.menu.Item")]
[Uses("ext.mixin.Queryable")]
[Uses("ext.Base")]
[Uses("ext.Component")]
[Uses("ext.util.Animate")]
[Uses("ext.util.ElementContainer")]
[Uses("ext.util.Focusable")]
[Uses("ext.mixin.ComponentDelegation")]
[Uses("ext.Mixin")]
[Uses("ext.mixin.Inheritable")]
[Uses("ext.util.Positionable")]
[Uses("ext.mixin.Bindable")]
[Uses("ext.mixin.Keyboard")]
[Uses("ext.mixin.Observable")]
[Uses("ext.mixin.Identifiable")]
[Uses("ext.state.Stateful")]
[Uses("ext.mixin.Accessible")]
[Uses("ext.util.Renderable")]
[Uses("ext.util.Floating")]
[Native("Ext.menu.Separator", require)]
/**
 * Adds a separator bar to a menu, used to divide logical groups of menu items. Generally you will
 * add one of these by using "-" in your call to add() or in your items config rather than creating one directly.
 * <p><b>Example:</b></p>
 * <pre>
 * Ext.create('Ext.menu.Menu', {
 *     width: 100,
 *     height: 100,
 *     floating: false,  // usually you want this set to True (default)
 *     renderTo: Ext.getBody(),  // usually rendered by it's containing component
 *     items: [{
 *         text: 'icon item',
 *         iconCls: 'add16'
 *     },{
 *         xtype: 'menuseparator'
 *     },{
 *        text: 'separator above'
 *     },{
 *        text: 'regular item'
 *     }]
 * });
 * </pre>
 * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Separator.html Original Ext JS documentation of 'Ext.menu.Separator'
 */
public class Separator extends ext.menu.Item {
  /**
   * @param config @inheritDoc
   */
  public function Separator(config:ext.menu.Separator = null) {
    super();
  }

  [ExtConfig]
  /**
   * The CSS class used by the separator item to show the incised line.
   * @default Ext.baseCSSPrefix + 'menu-item-separator'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.menu.Separator.html#cfg-separatorCls Original Ext JS documentation of 'separatorCls'
   */
  public native function get separatorCls():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set separatorCls(value:String):void;
}
}