package ext.mixin {
import ext.Component;
import ext.IMixin;

[Uses("ext.Mixin")]
[Uses("ext.mixin.Container")]
[Uses("ext.Base")]
[Mixin("ext.mixin.Container")]
/**
 * Common methods for both classic &amp; modern containers
 * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.mixin.Container.html Original Ext JS documentation of 'Ext.mixin.Container'
 * @see ext.mixin.Container
 */
public interface IContainer extends ext.IMixin {
  /**
   * <code>true</code> in this class to identify an object as an instantiated Container, or subclass thereof.
   * @default true
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.mixin.Container.html#property-isContainer Original Ext JS documentation of 'isContainer'
   */
  function get isContainer():Boolean;

  function set isContainer(value:Boolean):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * If <code>true</code>, this container will be marked as being a point in the hierarchy where
   * references to items with a specified <code>reference</code> config will be held. The container
   * will automatically become a referenceHolder if a <code>controller</code> is specified.
   * <p>See the introductory docs for <code>ext.container.Container</code> for more information
   * about references &amp; reference holders.</p>
   * @default false
   * @see #controller
   * @see ext.container.Container
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.mixin.Container.html#cfg-referenceHolder Original Ext JS documentation of 'referenceHolder'
   * @see #getReferenceHolder()
   * @see #setReferenceHolder()
   */
  function get referenceHolder():Boolean;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  function set referenceHolder(value:Boolean):void;

  /**
   * Returns the value of <code>referenceHolder</code>.
   * @see #referenceHolder
   */
  function getReferenceHolder():Boolean;

  /**
   * Returns an object holding the descendants of this view keyed by their
   * <code>reference</code>. This object should not be held
   * past the scope of the function calling this method. It will not be valid if items
   * are added or removed from this or any sub-container.
   * <p>The intended usage is shown here (assume there are 3 components with reference
   * values of "foo", "bar" and "baz" at some level below this container):</p>
   * <pre>
   *  onClick: function () {
   *      var refs = this.getReferences();
   *
   *      // using "refs" we can access any descendant by its "reference"
   *
   *      refs.foo.getValue() + refs.bar.getValue() + refs.baz.getValue();
   *  }
   * </pre>
   * <p>If <code>this</code> component has a <code>reference</code> assigned
   * to it, that is <b>not</b> included in this object. That reference is understood to
   * belong to the ancestor container configured as the <code>referenceHolder</code>.</p>
   * @since 5.0.0
   * @return An object with each child reference. This will be <code>null</code> if this
   * container has no descendants with a <code>reference</code>
   * specified.
   * @see ext.Component#reference
   * @see ext.mixin.Container#referenceHolder
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.mixin.Container.html#method-getReferences Original Ext JS documentation of 'getReferences'
   */
  function getReferences():Object;

  /**
   * Gets a reference to the component with the specified <code>reference</code> value.
   * <p>The method is a short-hand for the <code>lookupReference()</code> method.</p>
   * @since 6.0.1
   * @param key The name of the reference to lookup.
   * @return The referenced component or <code>null</code> if it is not found.
   * @see ext.mixin.Container#reference
   * @see ext.mixin.Container#lookupReference()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.mixin.Container.html#method-lookup Original Ext JS documentation of 'lookup'
   */
  function lookup(key:String):ext.Component;

  /**
   * Gets a reference to the component with the specified <code>reference</code> value.
   * <p>The <code>lookup()</code> method is a short-hand version of this method.</p>
   * @since 5.0
   * @param key The name of the reference to lookup.
   * @return The referenced component or <code>null</code> if it is not found.
   * @see ext.mixin.Container#reference
   * @see ext.mixin.Container#lookup()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.mixin.Container.html#method-lookupReference Original Ext JS documentation of 'lookupReference'
   */
  function lookupReference(key:String):ext.Component;

  /**
   * Sets the value of <code>referenceHolder</code>.
   * @param referenceHolder The new value.
   * @see #referenceHolder
   */
  function setReferenceHolder(referenceHolder:Boolean):void;
}
}