package ext.picker {
import ext.Component;

[Uses("ext.Component")]
[Uses("ext.util.Animate")]
[Uses("ext.Base")]
[Uses("ext.util.ElementContainer")]
[Uses("ext.util.Focusable")]
[Uses("ext.mixin.ComponentDelegation")]
[Uses("ext.Mixin")]
[Uses("ext.mixin.Inheritable")]
[Uses("ext.util.Positionable")]
[Uses("ext.mixin.Bindable")]
[Uses("ext.mixin.Keyboard")]
[Uses("ext.mixin.Observable")]
[Uses("ext.mixin.Identifiable")]
[Uses("ext.state.Stateful")]
[Uses("ext.mixin.Accessible")]
[Uses("ext.util.Renderable")]
[Uses("ext.util.Floating")]
[Native("Ext.picker.Month", require)]
/**
 * @see ext.picker.events.MonthPickerEvent.CANCEL_CLICK
 * @eventType ext.picker.events.MonthPickerEvent.CANCEL_CLICK
 */
[Event(name = 'onCancelClick', type = 'ext.picker.events.MonthPickerEvent')]
/**
 * @see ext.picker.events.MonthPicker_valueEvent.MONTH_CLICK
 * @eventType ext.picker.events.MonthPicker_valueEvent.MONTH_CLICK
 */
[Event(name = 'onMonthClick', type = 'ext.picker.events.MonthPicker_valueEvent')]
/**
 * @see ext.picker.events.MonthPicker_valueEvent.MONTH_DBLCLICK
 * @eventType ext.picker.events.MonthPicker_valueEvent.MONTH_DBLCLICK
 */
[Event(name = 'onMonthDblclick', type = 'ext.picker.events.MonthPicker_valueEvent')]
/**
 * @see ext.picker.events.MonthPicker_valueEvent.OK_CLICK
 * @eventType ext.picker.events.MonthPicker_valueEvent.OK_CLICK
 */
[Event(name = 'onOkClick', type = 'ext.picker.events.MonthPicker_valueEvent')]
/**
 * @see ext.picker.events.MonthPicker_valueEvent.SELECT
 * @eventType ext.picker.events.MonthPicker_valueEvent.SELECT
 */
[Event(name = 'onSelect', type = 'ext.picker.events.MonthPicker_valueEvent')]
/**
 * @see ext.picker.events.MonthPicker_valueEvent.YEAR_CLICK
 * @eventType ext.picker.events.MonthPicker_valueEvent.YEAR_CLICK
 */
[Event(name = 'onYearClick', type = 'ext.picker.events.MonthPicker_valueEvent')]
/**
 * @see ext.picker.events.MonthPicker_valueEvent.YEAR_DBLCLICK
 * @eventType ext.picker.events.MonthPicker_valueEvent.YEAR_DBLCLICK
 */
[Event(name = 'onYearDblclick', type = 'ext.picker.events.MonthPicker_valueEvent')]
/**
 * A month / year picker component. This class is used by the
 * <code>ext.picker.DatePicker</code> to allow browsing and selection of year and
 * months combinations, but may also be used as a standalone component.
 * <p><b>Example:</b></p>
 * <pre>
 * Ext.create({
 *     xtype: 'monthpicker',
 *     renderTo: document.body,
 *     value: new Date(),
 *     onSelect: function() {
 *         Ext.Msg.alert('Selected', this.getValue());
 *     },
 *     listeners: {
 *         okclick: 'onSelect',
 *         monthdblclick: 'onSelect',
 *         yeardblclick: 'onSelect',
 *         cancelclick: function () {
 *             this.setValue(new Date());
 *         }
 *     }
 * });
 * </pre>
 * @see ext.picker.DatePicker
 * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Month.html Original Ext JS documentation of 'Ext.picker.Month'
 */
public class MonthPicker extends ext.Component {
  /**
   * @param config @inheritDoc
   */
  public function MonthPicker(config:ext.picker.MonthPicker = null) {
    super();
  }

  [ExtConfig]
  /**
   * The base CSS class to apply to the picker element.
   * @default 'x-monthpicker'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Month.html#cfg-baseCls Original Ext JS documentation of 'baseCls'
   */
  override public native function get baseCls():String;

  [ExtConfig]
  /**
   * @private
   */
  override public native function set baseCls(value:String):void;

  [ExtConfig]
  /**
   * The text to display on the cancel button.
   * @default 'Cancel'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Month.html#cfg-cancelText Original Ext JS documentation of 'cancelText'
   */
  public native function get cancelText():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set cancelText(value:String):void;

  [ExtConfig]
  /**
   * The <code>ext.button.Button#ui</code> to use for the month picker's footer buttons.
   * @default 'default'
   * @see ext.button.Button#ui
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Month.html#cfg-footerButtonUI Original Ext JS documentation of 'footerButtonUI'
   */
  public native function get footerButtonUI():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set footerButtonUI(value:String):void;

  [ExtConfig]
  /**
   * The text to display on the ok button.
   * @default 'OK'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Month.html#cfg-okText Original Ext JS documentation of 'okText'
   */
  public native function get okText():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set okText(value:String):void;

  [ExtConfig]
  /**
   * The class to be added to selected items in the picker.
   * @default 'x-monthpicker-selected'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Month.html#cfg-selectedCls Original Ext JS documentation of 'selectedCls'
   */
  public native function get selectedCls():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set selectedCls(value:String):void;

  [ExtConfig]
  /**
   * True to show ok and cancel buttons below the picker.
   * @default true
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Month.html#cfg-showButtons Original Ext JS documentation of 'showButtons'
   */
  public native function get showButtons():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set showButtons(value:Boolean):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * The default value to set. See <code>setValue()</code>
   * @see #setValue()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Month.html#cfg-value Original Ext JS documentation of 'value'
   * @see #getValue()
   */
  public native function get value():*;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set value(value:*):void;

  /**
   * Modify the year display by passing an offset.
   * @param offset The offset to move by.
   * @default 10
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Month.html#method-adjustYear Original Ext JS documentation of 'adjustYear'
   */
  public native function adjustYear(offset:Number = 10):void;

  [ArrayElementType("Number")]
  /**
   * Gets the selected value. It is returned as an array [month, year]. It may
   * be a partial value, for example [null, 2010]. The month is returned as
   * 0 based.
   * @return The selected value
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Month.html#method-getValue Original Ext JS documentation of 'getValue'
   */
  public native function getValue():Array;

  /**
   * Checks whether the picker has a selection
   * @return Returns true if both a month and year have been selected
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Month.html#method-hasSelection Original Ext JS documentation of 'hasSelection'
   */
  public native function hasSelection():Boolean;

  /**
   * Set the value for the picker.
   * @param value The value to set. It can be a Date object, where the month/year will be extracted, or
   * it can be an array, with the month as the first index and the year as the second.
   * @return this
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.picker.Month.html#method-setValue Original Ext JS documentation of 'setValue'
   */
  public native function setValue(value:*):ext.picker.MonthPicker;
}
}