package ext.plugin {

[Uses("ext.plugin.AbstractPlugin")]
[Uses("ext.Base")]
[Native("Ext.plugin.LazyItems", require)]
/**
 * This plugin defers the execution cost of the instantiation and initialization of child components of un-rendered items.
 * <p>For example, in a <code>deferredRender</code> <code>ext.tab.TabPanel</code>, the un-rendered tabs
 * do not have to incur the cost of instantiating and initializing their descendant components until render.</p>
 * <p>This plugin allows that.</p>
 * <p>Add the items to the plugin:</p>
 * <pre>
 * {
 *     xtype: 'tabpanel',
 *     items: [{
 *         title: 'Tab One',
 *         plugins: {
 *             ptype: 'lazyitems',
 *             items: [... tab child items...]
 *         }
 *     }, {
 *         title: 'Tab One',
 *         plugins: {
 *             ptype: 'lazyitems',
 *             items: [... tab child items...]
 *         }
 *     }]
 * }
 * </pre>
 * @see ext.tab.TabPanel#deferredRender
 * @see ext.tab.TabPanel
 * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.plugin.LazyItems.html Original Ext JS documentation of 'Ext.plugin.LazyItems'
 */
public class LazyItemsPlugin extends ext.plugin.AbstractPlugin {
  /**
   * @param config @inheritDoc
   */
  public function LazyItemsPlugin(config:ext.plugin.LazyItemsPlugin = null) {
    super();
  }
}
}