package ext.slider {
import ext.Base;
import ext.form.field.BaseField;
import ext.form.field.IField;

[Uses("ext.form.field.BaseField")]
[Uses("ext.form.Labelable")]
[Uses("ext.Mixin")]
[Uses("ext.Base")]
[Uses("ext.Component")]
[Uses("ext.util.Animate")]
[Uses("ext.util.ElementContainer")]
[Uses("ext.util.Focusable")]
[Uses("ext.mixin.ComponentDelegation")]
[Uses("ext.mixin.Inheritable")]
[Uses("ext.util.Positionable")]
[Uses("ext.mixin.Bindable")]
[Uses("ext.mixin.Keyboard")]
[Uses("ext.mixin.Observable")]
[Uses("ext.mixin.Identifiable")]
[Uses("ext.state.Stateful")]
[Uses("ext.mixin.Accessible")]
[Uses("ext.util.Renderable")]
[Uses("ext.util.Floating")]
[Uses("ext.form.field.Field")]
[Native("Ext.slider.Multi", require)]
/**
 * @see ext.slider.events.MultiSlider_newValue_oldValueEvent.BEFORE_CHANGE
 * @eventType ext.slider.events.MultiSlider_newValue_oldValueEvent.BEFORE_CHANGE
 */
[Event(name = 'onBeforeChange', type = 'ext.slider.events.MultiSlider_newValue_oldValueEvent')]
/**
 * @see ext.slider.events.MultiSlider_newValue_thumbEvent.CHANGE
 * @eventType ext.slider.events.MultiSlider_newValue_thumbEvent.CHANGE
 */
[Event(name = 'onChange', type = 'ext.slider.events.MultiSlider_newValue_thumbEvent')]
/**
 * @see ext.slider.events.MultiSlider_newValue_thumbEvent.CHANGE_COMPLETE
 * @eventType ext.slider.events.MultiSlider_newValue_thumbEvent.CHANGE_COMPLETE
 */
[Event(name = 'onChangeComplete', type = 'ext.slider.events.MultiSlider_newValue_thumbEvent')]
/**
 * @see ext.slider.events.MultiSlider_eEvent.DRAG
 * @eventType ext.slider.events.MultiSlider_eEvent.DRAG
 */
[Event(name = 'onDrag', type = 'ext.slider.events.MultiSlider_eEvent')]
/**
 * @see ext.slider.events.MultiSlider_eEvent.DRAG_END
 * @eventType ext.slider.events.MultiSlider_eEvent.DRAG_END
 */
[Event(name = 'onDragEnd', type = 'ext.slider.events.MultiSlider_eEvent')]
/**
 * @see ext.slider.events.MultiSlider_eEvent.DRAG_START
 * @eventType ext.slider.events.MultiSlider_eEvent.DRAG_START
 */
[Event(name = 'onDragStart', type = 'ext.slider.events.MultiSlider_eEvent')]
/**
 * Slider which supports vertical or horizontal orientation, keyboard adjustments, configurable snapping, axis clicking
 * and animation. Can be added as an item to any container.
 * <p>Sliders can be created with more than one thumb handle by passing an array of values instead of a single one:</p>
 * <p><b>Example:</b></p>
 * <pre>
 * Ext.create('Ext.slider.Multi', {
 *     width: 200,
 *     values: [25, 50, 75],
 *     increment: 5,
 *     minValue: 0,
 *     maxValue: 100,
 *
 *     // this defaults to true, setting to false allows the thumbs to pass each other
 *     constrainThumbs: false,
 *     renderTo: Ext.getBody()
 * });
 * </pre>
 * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.slider.Multi.html Original Ext JS documentation of 'Ext.slider.Multi'
 */
public class MultiSlider extends ext.form.field.BaseField {
  /**
   * @param config @inheritDoc
   */
  public function MultiSlider(config:ext.slider.MultiSlider = null) {
    super();
  }

  [ExtConfig]
  /**
   * Turn on or off animation. May be an animation configuration object:
   * <pre>
   * animate: {
   *     duration: 3000,
   *     easing: 'easeIn'
   * }
   * </pre>
   * @default true
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.slider.Multi.html#cfg-animate Original Ext JS documentation of 'animate'
   */
  public native function get animated():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set animated(value:*):void;

  [ExtConfig]
  /**
   * Determines whether or not clicking on the Slider axis will change the slider.
   * @default true
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.slider.Multi.html#cfg-clickToChange Original Ext JS documentation of 'clickToChange'
   */
  public native function get clickToChange():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set clickToChange(value:Boolean):void;

  [ExtConfig]
  /**
   * True to disallow thumbs from overlapping one another.
   * @default true
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.slider.Multi.html#cfg-constrainThumbs Original Ext JS documentation of 'constrainThumbs'
   */
  public native function get constrainThumbs():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set constrainThumbs(value:Boolean):void;

  [ExtConfig]
  /**
   * The number of decimal places to which to round the Slider's value.
   * <p>To disable rounding, configure as <b>false</b>.</p>
   * @default 0
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.slider.Multi.html#cfg-decimalPrecision Original Ext JS documentation of 'decimalPrecision'
   */
  public native function get decimalPrecision():*;

  [ExtConfig]
  /**
   * @private
   */
  public native function set decimalPrecision(value:*):void;

  /**
   * This property is used to determine the property of a <code>bind</code> config that is just
   * the value. For example, if <code>defaultBindProperty="value"</code>, then this shorthand
   * <code>bind</code> config:
   * <pre>
   *  bind: '{name}'
   * </pre>
   * <p>Is equivalent to this object form:</p>
   * <pre>
   *  bind: {
   *      value: '{name}'
   *  }
   * </pre>
   * <p>The <code>defaultBindProperty</code> is set to "value" for form fields and to "store" for
   * grids and trees.</p>
   * @default 'values'
   * @see #bind
   * @see #defaultBindProperty
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.slider.Multi.html#property-defaultBindProperty Original Ext JS documentation of 'defaultBindProperty'
   */
  override public native function get defaultBindProperty():String;

  /**
   * @private
   */
  override public native function set defaultBindProperty(value:String):void;

  /**
   * True while the thumb is in a drag operation
   * @default false
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.slider.Multi.html#property-dragging Original Ext JS documentation of 'dragging'
   */
  public native function get dragging():Boolean;

  /**
   * @private
   */
  public native function set dragging(value:Boolean):void;

  [ExtConfig]
  /**
   * How many units to change the slider when adjusting by drag and drop. Use this option to enable 'snapping'.
   * @default 0
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.slider.Multi.html#cfg-increment Original Ext JS documentation of 'increment'
   */
  public native function get increment():Number;

  [ExtConfig]
  /**
   * @private
   */
  public native function set increment(value:Number):void;

  [ExtConfig]
  /**
   * How many units to change the Slider when adjusting with keyboard navigation. If the increment
   * config is larger, it will be used instead.
   * @default 1
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.slider.Multi.html#cfg-keyIncrement Original Ext JS documentation of 'keyIncrement'
   */
  public native function get keyIncrement():Number;

  [ExtConfig]
  /**
   * @private
   */
  public native function set keyIncrement(value:Number):void;

  [ExtConfig]
  /**
   * The maximum value for the Slider.
   * @default 100
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.slider.Multi.html#cfg-maxValue Original Ext JS documentation of 'maxValue'
   * @see #setMaxValue()
   */
  public native function get maxValue():Number;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set maxValue(value:Number):void;

  [ExtConfig]
  /**
   * The minimum value for the Slider.
   * @default 0
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.slider.Multi.html#cfg-minValue Original Ext JS documentation of 'minValue'
   * @see #setMinValue()
   */
  public native function get minValue():Number;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set minValue(value:Number):void;

  [ExtConfig]
  /**
   * How many units to change the Slider when using PageUp and PageDown keys.
   * @default 10
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.slider.Multi.html#cfg-pageSize Original Ext JS documentation of 'pageSize'
   */
  public native function get pageSize():Number;

  [ExtConfig]
  /**
   * @private
   */
  public native function set pageSize(value:Number):void;

  /**
   * Array containing references to each thumb
   * @default []
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.slider.Multi.html#property-thumbs Original Ext JS documentation of 'thumbs'
   */
  public native function get thumbs():Array;

  /**
   * @private
   */
  public native function set thumbs(value:Array):void;

  [ExtConfig]
  /**
   * A function used to display custom text for the slider tip or the name of the
   * method on the corresponding <code>ext.app.ViewController</code>.
   * <p>Defaults to null, which will use the default on the plugin.</p>
   * <ul>
   * <li><code>thumb</code> : ext.Base (optional)
   * The Thumb that the Tip is attached to
   * </li>
   * <li><code>return</code> : String (optional)
   * The text to display in the tip
   * </li>
   * </ul>
   * @see ext.app.ViewController
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.slider.Multi.html#property-thumb Original Ext JS documentation of 'thumb'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.slider.Multi.html#property-return Original Ext JS documentation of 'return'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.slider.Multi.html#cfg-tipText Original Ext JS documentation of 'tipText'
   */
  public native function get tipText():Function;

  [ExtConfig]
  /**
   * @private
   */
  public native function set tipText(value:Function):void;

  [ExtConfig]
  /**
   * True to use an <code>ext.slider.SliderTip</code> to display tips for the value. This option may also
   * provide a configuration object for an <code>ext.slider.SliderTip</code>.
   * @default true
   * @see ext.slider.SliderTip
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.slider.Multi.html#cfg-useTips Original Ext JS documentation of 'useTips'
   */
  public native function get useTips():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set useTips(value:*):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * A value with which to initialize the slider. Setting this will only result in the creation
   * of a single slider thumb; if you want multiple thumbs then use the <code>values</code> config instead.
   * <p>Defaults to #minValue.</p>
   * @see #values
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.slider.Multi.html#cfg-value Original Ext JS documentation of 'value'
   * @see #getValue()
   * @see #setValue()
   */
  override public native function get value():Object;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  override public native function set value(value:Object):void;

  [ArrayElementType("Number")]
  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * Array of Number values with which to initalize the slider. A separate slider thumb will be created for each value
   * in this array. This will take precedence over the single <code>value</code> config.
   * @see #value
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.slider.Multi.html#cfg-values Original Ext JS documentation of 'values'
   * @see #getValues()
   */
  public native function get values():Array;

  [ExtConfig]
  /**
   * @private
   */
  public native function set values(value:Array):void;

  [ExtConfig]
  /**
   * Orient the Slider vertically rather than horizontally.
   * @default false
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.slider.Multi.html#cfg-vertical Original Ext JS documentation of 'vertical'
   */
  public native function get vertical():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set vertical(value:Boolean):void;

  [ExtConfig]
  /**
   * Set to <code>true</code> to calculate snap points based on <code>increment</code>s from zero as opposed to
   * from this Slider's <code>minValue</code>.
   * <p>By Default, valid snap points are calculated starting <code>increment</code>s from the <code>minValue</code></p>
   * @default false
   * @see #increment
   * @see #minValue
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.slider.Multi.html#cfg-zeroBasedSnapping Original Ext JS documentation of 'zeroBasedSnapping'
   */
  public native function get zeroBasedSnapping():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set zeroBasedSnapping(value:Boolean):void;

  /**
   * Creates a new thumb and adds it to the slider
   * @param value The initial value to set on the thumb.
   * @default 0
   * @return The thumb
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.slider.Multi.html#method-addThumb Original Ext JS documentation of 'addThumb'
   */
  public native function addThumb(value:Number = 0):ext.Base;

  /**
   * Returns the current value of the slider
   * @return The current value of the slider at the given index, or an array of all thumb values if
   * no index is given.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.slider.Multi.html#method-getValue Original Ext JS documentation of 'getValue'
   */
  override public native function getValue():*;

  [ArrayElementType("Number")]
  /**
   * Returns an array of values - one for the location of each thumb
   * @return The set of thumb values
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.slider.Multi.html#method-getValues Original Ext JS documentation of 'getValues'
   */
  public native function getValues():Array;

  /**
   * Sets the maximum value for the slider instance. If the current value is more than the maximum value, the current
   * value will be changed.
   * @param val The new maximum value
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.slider.Multi.html#method-setMaxValue Original Ext JS documentation of 'setMaxValue'
   */
  public native function setMaxValue(val:Number):ext.slider.SliderField;

  /**
   * Sets the minimum value for the slider instance. If the current value is less than the minimum value, the current
   * value will be changed.
   * @param val The new minimum value
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.slider.Multi.html#method-setMinValue Original Ext JS documentation of 'setMinValue'
   */
  public native function setMinValue(val:Number):ext.slider.SliderField;

  /**
   * Programmatically sets the value of the Slider. Ensures that the value is constrained within the minValue and
   * maxValue.
   * <p>Setting the second slider's value without animation:</p>
   * <pre>
   * mySlider.setValue(1, 50, false);
   * </pre>
   * <p>Setting multiple values with animation:</p>
   * <pre>
   * mySlider.setValue([20, 40, 60], true);
   * </pre>
   * @param value The value to set
   * @return this
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.slider.Multi.html#method-setValue Original Ext JS documentation of 'setValue'
   */
  override public native function setValue(value:*):ext.form.field.IField;

  /**
   * Synchronizes thumbs position to the proper proportion of the total component width based on the current slider
   * <code>value</code>. This will be called automatically when the Slider is resized by a layout, but if it is rendered
   * auto width, this method can be called from another resize handler to sync the Slider if necessary.
   * @see #value
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.slider.Multi.html#method-syncThumbs Original Ext JS documentation of 'syncThumbs'
   */
  public native function syncThumbs():void;
}
}