package ext.tip {

[Uses("ext.tip.ToolTip")]
[Uses("ext.tip.Tip")]
[Uses("ext.panel.Panel")]
[Uses("ext.container.DockingContainer")]
[Uses("ext.Base")]
[Uses("ext.container.Container")]
[Uses("ext.mixin.Queryable")]
[Uses("ext.Component")]
[Uses("ext.util.Animate")]
[Uses("ext.util.ElementContainer")]
[Uses("ext.util.Focusable")]
[Uses("ext.mixin.ComponentDelegation")]
[Uses("ext.Mixin")]
[Uses("ext.mixin.Inheritable")]
[Uses("ext.util.Positionable")]
[Uses("ext.mixin.Bindable")]
[Uses("ext.mixin.Keyboard")]
[Uses("ext.mixin.Observable")]
[Uses("ext.mixin.Identifiable")]
[Uses("ext.state.Stateful")]
[Uses("ext.mixin.Accessible")]
[Uses("ext.util.Renderable")]
[Uses("ext.util.Floating")]
[Uses("ext.mixin.Container")]
[Native("Ext.tip.QuickTip", require)]
/**
 * A specialized tooltip class for tooltips that can be specified in markup and automatically managed
 * by the global <code>ext.tip.SQuickTipManager</code> instance. See the QuickTipManager documentation for
 * additional usage details and examples.
 * <p><b>Example:</b></p>
 * <pre>
 *  Ext.tip.QuickTipManager.init(); // Instantiate the QuickTipManager
 *
 *  Ext.create('Ext.Button', {
 *
 *      renderTo: Ext.getBody(),
 *      text: 'My Button',
 *      listeners: {
 *
 *          afterrender: function(me) {
 *
 *              // Register the new tip with an element's ID
 *              Ext.tip.QuickTipManager.register({
 *                  target: me.getId(), // Target button's ID
 *                  title : 'My Tooltip',  // QuickTip Header
 *                  text  : 'My Button has a QuickTip' // Tip content
 *              });
 *
 *          }
 *      }
 *  });
 * </pre>
 * @see ext.tip.SQuickTipManager
 * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.tip.QuickTip.html Original Ext JS documentation of 'Ext.tip.QuickTip'
 */
public class QuickTip extends ext.tip.ToolTip {
  /**
   * @param config @inheritDoc
   */
  public function QuickTip(config:ext.tip.QuickTip = null) {
    super();
  }

  [ExtConfig]
  /**
   * -- hidden for Ext.tip.QuickTip - see #cfg-text
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.tip.QuickTip.html#cfg-html Original Ext JS documentation of 'html'
   * @see #setHtml()
   */
  override public native function get html():*;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  override public native function set html(value:*):void;

  [ExtConfig]
  /**
   * <code>true</code> to automatically use the element's DOM title value if available.
   * @default false
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.tip.QuickTip.html#cfg-interceptTitles Original Ext JS documentation of 'interceptTitles'
   */
  public native function get interceptTitles():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set interceptTitles(value:Boolean):void;

  [ExtConfig]
  /**
   * The target HTMLElement, <code>ext.dom.Element</code> or id to associate with this Quicktip.
   * <p>Defaults to the document.</p>
   * @see ext.dom.Element
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.tip.QuickTip.html#cfg-target Original Ext JS documentation of 'target'
   * @see #setTarget()
   */
  override public native function get target():*;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  override public native function set target(value:*):void;

  [ExtConfig]
  /**
   * An HTML fragment, or a <code>ext.dom.SDomHelper</code> specification to use as the layout element content.
   * The HTML content is added after the component is rendered, so the document will not contain this HTML at the time
   * the <code>event:onRender</code> event is fired. This content is inserted into the body <i>before</i> any configured <code>contentEl</code>
   * is appended.
   * @see ext.dom.SDomHelper
   * @see #event:onRender
   * @see #contentEl
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.tip.QuickTip.html#cfg-text Original Ext JS documentation of 'text'
   */
  public native function get text():*;

  [ExtConfig]
  /**
   * @private
   */
  public native function set text(value:*):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * The title text to be used to display in the Tip header. May be a string
   * (including HTML tags) or an <code>ext.panel.PanelTitle</code> config object.
   * @default '&amp;160;'
   * @see ext.panel.PanelTitle
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.tip.QuickTip.html#cfg-title Original Ext JS documentation of 'title'
   * @see #getTitle()
   * @see #setTitle()
   */
  override public native function get title():*;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  override public native function set title(value:*):void;

  /**
   * Hides a visible tip or cancels an impending show for a particular element.
   * @param el The element that is the target of
   * the tip or ID of the element.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.tip.QuickTip.html#method-cancelShow Original Ext JS documentation of 'cancelShow'
   */
  public native function cancelShow(el:*):void;

  /**
   * Configures a new quick tip instance and assigns it to a target element.
   * <p>For example usage, see the <code>ext.tip.SQuickTipManager</code> class header.</p>
   * @param config The config object with the following properties:
   * @param config.target The target HTMLElement, <code>ext.dom.Element</code> or
   * id to associate with this Quicktip. See <code>ext.tip.QuickTip#target</code>.
   * @param [config.text] Tip body content. See <code>ext.tip.QuickTip#text</code>.
   * @param [config.title] Tip header. See <code>ext.tip.QuickTip#title</code>.
   * @param [config.autoHide] False to prevent the tip from automatically hiding on
   * mouseleave. See <code>ext.tip.QuickTip#autoHide</code>.
   * @param [config.cls] An optional extra CSS class that will be added to the tip. See
   * <code>ext.tip.QuickTip#cls</code>.
   * @param [config.dismissDelay] Delay in milliseconds before the tooltip automatically
   * hides (overrides singleton value). See <code>ext.tip.QuickTip#dismissDelay</code>.
   * @param [config.width] Tip width in pixels. See <code>ext.tip.QuickTip#width</code>.
   * @see ext.tip.SQuickTipManager
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.tip.QuickTip.html#method-register Original Ext JS documentation of 'register'
   * @see ext.dom.Element
   * @see ext.tip.QuickTip#target
   * @see ext.tip.QuickTip#text
   * @see ext.tip.QuickTip#title
   * @see ext.tip.QuickTip#autoHide
   * @see ext.tip.QuickTip#cls
   * @see ext.tip.QuickTip#dismissDelay
   * @see ext.tip.QuickTip#width
   */
  public native function register(config:Object):void;

  /**
   * Removes this quick tip from its element and destroys it.
   * @param el The element from which the quick tip
   * is to be removed or ID of the element.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.tip.QuickTip.html#method-unregister Original Ext JS documentation of 'unregister'
   */
  public native function unregister(el:*):void;
}
}