package ext.toolbar {
import ext.container.Container;
import ext.data.TreeStore;
import ext.util.IFocusableContainer;

[Uses("ext.container.Container")]
[Uses("ext.util.FocusableContainer")]
[Uses("ext.Mixin")]
[Uses("ext.Base")]
[Uses("ext.mixin.Queryable")]
[Uses("ext.Component")]
[Uses("ext.util.Animate")]
[Uses("ext.util.ElementContainer")]
[Uses("ext.util.Focusable")]
[Uses("ext.mixin.ComponentDelegation")]
[Uses("ext.mixin.Inheritable")]
[Uses("ext.util.Positionable")]
[Uses("ext.mixin.Bindable")]
[Uses("ext.mixin.Keyboard")]
[Uses("ext.mixin.Observable")]
[Uses("ext.mixin.Identifiable")]
[Uses("ext.state.Stateful")]
[Uses("ext.mixin.Accessible")]
[Uses("ext.util.Renderable")]
[Uses("ext.util.Floating")]
[Uses("ext.mixin.Container")]
[Native("Ext.toolbar.Breadcrumb", require)]
/**
 * @see ext.toolbar.events.Breadcrumb_node_prevNodeEvent.CHANGE
 * @eventType ext.toolbar.events.Breadcrumb_node_prevNodeEvent.CHANGE
 */
[Event(name = 'onChange', type = 'ext.toolbar.events.Breadcrumb_node_prevNodeEvent')]
/**
 * @see ext.toolbar.events.Breadcrumb_node_prevNodeEvent.SELECTION_CHANGE
 * @eventType ext.toolbar.events.Breadcrumb_node_prevNodeEvent.SELECTION_CHANGE
 */
[Event(name = 'onSelectionChange', type = 'ext.toolbar.events.Breadcrumb_node_prevNodeEvent')]
/**
 * A toolbar that displays hierarchical data from a <code>ext.data.TreeStore</code>
 * as a trail of breadcrumb buttons. Each button represents a node in the store. A click
 * on a button will "select" that node in the tree. Non-leaf nodes will display their
 * child nodes on a dropdown menu of the corresponding button in the breadcrumb trail,
 * and a click on an item in the menu will trigger selection of the corresponding child
 * node.
 * <p>The selection can be set programmatically using <code>setSelection()</code>, or retrieved
 * using <code>getSelection()</code>.</p>
 * @see ext.data.TreeStore
 * @see #setSelection()
 * @see #getSelection()
 * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.toolbar.Breadcrumb.html Original Ext JS documentation of 'Ext.toolbar.Breadcrumb'
 */
public class Breadcrumb extends ext.container.Container implements ext.util.IFocusableContainer {
  /**
   * @param config @inheritDoc
   */
  public function Breadcrumb(config:ext.toolbar.Breadcrumb = null) {
    super();
  }

  [ExtConfig]
  /**
   * DOM tabIndex attribute to set on the
   * active Focusable child of this container when using the "Roaming tabindex"
   * technique.
   * @default 0
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.FocusableContainer.html#cfg-activeChildTabIndex Original Ext JS documentation of 'activeChildTabIndex'
   */
  public native function get activeChildTabIndex():Number;

  [ExtConfig]
  /**
   * @private
   */
  public native function set activeChildTabIndex(value:Number):void;

  [ExtConfig]
  /**
   * Set this to <code>true</code> to enable focusing
   * disabled children via keyboard.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.FocusableContainer.html#cfg-allowFocusingDisabledChildren Original Ext JS documentation of 'allowFocusingDisabledChildren'
   */
  public native function get allowFocusingDisabledChildren():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set allowFocusingDisabledChildren(value:Boolean):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * Button UI to use for breadcrumb items. Use <code>extjsBreadcrumbUi</code> to
   * add special styling to the breadcrumb arrows
   * @default 'plain-toolbar'
   * @see #extjsBreadcrumbUi
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.toolbar.Breadcrumb.html#cfg-buttonUI Original Ext JS documentation of 'buttonUI'
   * @see #getButtonUI()
   * @see #setButtonUI()
   */
  public native function get buttonUI():String;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set buttonUI(value:String):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * The name of the field in the data model to display in the navigation items of
   * this breadcrumb toolbar
   * @default 'text'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.toolbar.Breadcrumb.html#cfg-displayField Original Ext JS documentation of 'displayField'
   * @see #getDisplayField()
   * @see #setDisplayField()
   */
  public native function get displayField():String;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set displayField(value:String):void;

  [ExtConfig]
  /**
   * Enable or disable
   * navigation with arrow keys for this FocusableContainer. This option may
   * be useful with nested FocusableContainers such as Grid column headers,
   * when only the root container should handle keyboard events.
   * @default true
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.FocusableContainer.html#cfg-enableFocusableContainer Original Ext JS documentation of 'enableFocusableContainer'
   */
  public native function get enableFocusableContainer():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set enableFocusableContainer(value:Boolean):void;

  /**
   * @inheritDoc
   */
  public native function get focusableContainerEl():*;

  /**
   * @inheritDoc
   */
  public native function set focusableContainerEl(value:*):void;

  [ExtConfig]
  /**
   * DOM tabIndex attribute to set on
   * inactive Focusable children of this container when using the "Roaming tabindex"
   * technique. This value rarely needs to be changed from its default.
   * @default -1
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.FocusableContainer.html#cfg-inactiveChildTabIndex Original Ext JS documentation of 'inactiveChildTabIndex'
   */
  public native function get inactiveChildTabIndex():Number;

  [ExtConfig]
  /**
   * @private
   */
  public native function set inactiveChildTabIndex(value:Number):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * The overflowHandler for this Breadcrumb:
   * <ul>
   * <li><code>null</code> - hidden overflow</li>
   * <li><code>'scroller'</code> to render left/right scroller buttons on either side of the breadcrumb</li>
   * <li><code>'menu'</code> to render the overflowing buttons as items of an overflow menu.</li>
   * </ul>
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.toolbar.Breadcrumb.html#cfg-overflowHandler Original Ext JS documentation of 'overflowHandler'
   * @see #getOverflowHandler()
   * @see #setOverflowHandler()
   */
  public native function get overflowHandler():String;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set overflowHandler(value:String):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * The selected node, or <code>"root"</code> to select the root node
   * @default 'root'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.toolbar.Breadcrumb.html#cfg-selection Original Ext JS documentation of 'selection'
   * @see #getSelection()
   * @see #setSelection()
   */
  public native function get selection():*;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set selection(value:*):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * Controls whether or not icons of tree nodes are displayed in the breadcrumb
   * buttons. There are 3 possible values for this config:
   * <ol>
   * <li>
   * <p>unspecified (<code>null</code>) - the default value. In this mode only icons that are
   * specified in the tree data using (<code>icon</code>
   * or <code>iconCls</code> will be displayed, but the
   * default "folder" and "leaf" icons will not be displayed.</p>
   * </li>
   * <li>
   * <p><code>true</code> - Icons specified in the tree data will be displayed, and the default
   * "folder" and "leaf" icons will be displayed for nodes that do not specify
   * an <code>icon</code> or <code>iconCls</code>.</p>
   * </li>
   * <li>
   * <p><code>false</code> - No icons will be displayed in the breadcrumb buttons, only text.</p>
   * </li>
   * </ol>
   * @see ext.data.NodeInterface#icon
   * @see ext.data.NodeInterface#iconCls
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.toolbar.Breadcrumb.html#cfg-showIcons Original Ext JS documentation of 'showIcons'
   * @see #getShowIcons()
   * @see #setShowIcons()
   */
  public native function get showIcons():Boolean;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set showIcons(value:Boolean):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * Controls whether or not icons of tree nodes are displayed in the breadcrumb
   * menu items. There are 3 possible values for this config:
   * <ol>
   * <li>
   * <p>unspecified (<code>null</code>) - the default value. In this mode only icons that are
   * specified in the tree data using (<code>icon</code>
   * or <code>iconCls</code> will be displayed, but the
   * default "folder" and "leaf" icons will not be displayed.</p>
   * </li>
   * <li>
   * <p><code>true</code> - Icons specified in the tree data will be displayed, and the default
   * "folder" and "leaf" icons will be displayed for nodes that do not specify
   * an <code>icon</code> or <code>iconCls</code>.</p>
   * </li>
   * <li>
   * <p><code>false</code> - No icons will be displayed on the breadcrumb menu items, only text.</p>
   * </li>
   * </ol>
   * @see ext.data.NodeInterface#icon
   * @see ext.data.NodeInterface#iconCls
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.toolbar.Breadcrumb.html#cfg-showMenuIcons Original Ext JS documentation of 'showMenuIcons'
   * @see #getShowMenuIcons()
   * @see #setShowMenuIcons()
   */
  public native function get showMenuIcons():Boolean;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set showMenuIcons(value:Boolean):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * The TreeStore that this breadcrumb toolbar should use as its data source
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.toolbar.Breadcrumb.html#cfg-store Original Ext JS documentation of 'store'
   * @see #getStore()
   * @see #setStore()
   */
  public native function get store():ext.data.TreeStore;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set store(value:ext.data.TreeStore):void;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * <code>false</code> to use regular <code>ext.button.Button</code>s instead of <code>ext.button.SplitButton</code>. When <code>true</code>, a click on the body of a button
   * will navigate to the specified node, and a click on the arrow will show a menu
   * containing the the child nodes. When <code>false</code>, the only mode of navigation is
   * the menu, since a click anywhere on the button will show the menu.
   * @default true
   * @see ext.button.Button
   * @see ext.button.SplitButton
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.toolbar.Breadcrumb.html#cfg-useSplitButtons Original Ext JS documentation of 'useSplitButtons'
   * @see #getUseSplitButtons()
   * @see #setUseSplitButtons()
   */
  public native function get useSplitButtons():Boolean;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set useSplitButtons(value:Boolean):void;

  /**
   * Returns the value of <code>buttonUI</code>.
   * @see #buttonUI
   */
  public native function getButtonUI():String;

  /**
   * Returns the value of <code>displayField</code>.
   * @see #displayField
   */
  public native function getDisplayField():String;

  /**
   * Returns the value of <code>overflowHandler</code>.
   * @see #overflowHandler
   */
  public native function getOverflowHandler():String;

  /**
   * Returns the value of <code>selection</code>.
   * @see #selection
   */
  public native function getSelection():*;

  /**
   * Returns the value of <code>showIcons</code>.
   * @see #showIcons
   */
  public native function getShowIcons():Boolean;

  /**
   * Returns the value of <code>showMenuIcons</code>.
   * @see #showMenuIcons
   */
  public native function getShowMenuIcons():Boolean;

  /**
   * Returns the value of <code>store</code>.
   * @see #store
   */
  public native function getStore():ext.data.TreeStore;

  /**
   * Returns the value of <code>useSplitButtons</code>.
   * @see #useSplitButtons
   */
  public native function getUseSplitButtons():Boolean;

  /**
   * Sets the value of <code>buttonUI</code>.
   * @param buttonUI The new value.
   * @see #buttonUI
   */
  public native function setButtonUI(buttonUI:String):void;

  /**
   * Sets the value of <code>displayField</code>.
   * @param displayField The new value.
   * @see #displayField
   */
  public native function setDisplayField(displayField:String):void;

  /**
   * Sets the value of <code>overflowHandler</code>.
   * @param overflowHandler The new value.
   * @see #overflowHandler
   */
  public native function setOverflowHandler(overflowHandler:String):void;

  /**
   * Sets the value of <code>selection</code>.
   * @param selection The new value.
   * @see #selection
   */
  public native function setSelection(selection:*):void;

  /**
   * Sets the value of <code>showIcons</code>.
   * @param showIcons The new value.
   * @see #showIcons
   */
  public native function setShowIcons(showIcons:Boolean):void;

  /**
   * Sets the value of <code>showMenuIcons</code>.
   * @param showMenuIcons The new value.
   * @see #showMenuIcons
   */
  public native function setShowMenuIcons(showMenuIcons:Boolean):void;

  /**
   * Sets the value of <code>store</code>.
   * @param store The new value.
   * @see #store
   */
  public native function setStore(store:ext.data.TreeStore):void;

  /**
   * Sets the value of <code>useSplitButtons</code>.
   * @param useSplitButtons The new value.
   * @see #useSplitButtons
   */
  public native function setUseSplitButtons(useSplitButtons:Boolean):void;
}
}