package ext.util {

[Uses("ext.util.Observable")]
[Uses("ext.mixin.Observable")]
[Uses("ext.Mixin")]
[Uses("ext.Base")]
[Uses("ext.mixin.Identifiable")]
[Native("Ext.util.ClickRepeater", require)]
/**
 * @see ext.util.events.ClickRepeater_eEvent.CLICK
 * @eventType ext.util.events.ClickRepeater_eEvent.CLICK
 */
[Event(name = 'onClick', type = 'ext.util.events.ClickRepeater_eEvent')]
/**
 * @see ext.util.events.ClickRepeater_eEvent.MOUSE_DOWN
 * @eventType ext.util.events.ClickRepeater_eEvent.MOUSE_DOWN
 */
[Event(name = 'onMouseDown', type = 'ext.util.events.ClickRepeater_eEvent')]
/**
 * @see ext.util.events.ClickRepeater_eEvent.MOUSE_UP
 * @eventType ext.util.events.ClickRepeater_eEvent.MOUSE_UP
 */
[Event(name = 'onMouseUp', type = 'ext.util.events.ClickRepeater_eEvent')]
/**
 * A wrapper class which can be applied to any element. Fires a "click" event while the
 * mouse is pressed. The interval between firings may be specified in the config but
 * defaults to 20 milliseconds.
 * <p>Optionally, a CSS class may be applied to the element during the time it is pressed.</p>
 * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.ClickRepeater.html Original Ext JS documentation of 'Ext.util.ClickRepeater'
 */
public class ClickRepeater extends ext.util.Observable {
  /**
   * Creates new ClickRepeater.
   * @param el The element or its ID to listen on
   * @param config Config object.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.ClickRepeater.html#method-constructor Original Ext JS documentation of 'constructor'
   */
  public function ClickRepeater(el:*, config:ext.util.ClickRepeater = null) {
    super();
  }

  [ExtConfig]
  /**
   * True if autorepeating should start slowly and accelerate.
   * "interval" and "delay" are ignored.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.ClickRepeater.html#cfg-accelerate Original Ext JS documentation of 'accelerate'
   */
  public native function get accelerate():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set accelerate(value:Boolean):void;

  [ExtConfig]
  /**
   * The initial delay before the repeating event begins firing.
   * Similar to an autorepeat key delay.
   * @default 250
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.ClickRepeater.html#cfg-delay Original Ext JS documentation of 'delay'
   */
  public native function get delay():Number;

  [ExtConfig]
  /**
   * @private
   */
  public native function set delay(value:Number):void;

  [ExtConfig]
  /**
   * The element to act as a button.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.ClickRepeater.html#cfg-el Original Ext JS documentation of 'el'
   */
  public native function get el():*;

  [ExtConfig]
  /**
   * @private
   */
  public native function set el(value:*):void;

  [ExtConfig]
  /**
   * The interval between firings of the "click" event (in milliseconds).
   * @default 20
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.ClickRepeater.html#cfg-interval Original Ext JS documentation of 'interval'
   */
  public native function get interval():Number;

  [ExtConfig]
  /**
   * @private
   */
  public native function set interval(value:Number):void;

  [ExtConfig]
  /**
   * A CSS class name to be applied to the element while pressed.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.ClickRepeater.html#cfg-pressedCls Original Ext JS documentation of 'pressedCls'
   */
  public native function get pressedCls():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set pressedCls(value:String):void;

  [ExtConfig]
  /**
   * True to prevent the default click event
   * @default true
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.ClickRepeater.html#cfg-preventDefault Original Ext JS documentation of 'preventDefault'
   */
  public native function get preventDefault():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set preventDefault(value:Boolean):void;

  [ExtConfig]
  /**
   * True to stop the default click event
   * @default false
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.ClickRepeater.html#cfg-stopDefault Original Ext JS documentation of 'stopDefault'
   */
  public native function get stopDefault():Boolean;

  [ExtConfig]
  /**
   * @private
   */
  public native function set stopDefault(value:Boolean):void;

  /**
   * Disables the repeater and stops events from firing.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.ClickRepeater.html#method-disable Original Ext JS documentation of 'disable'
   */
  public native function disable(force:*):void;

  /**
   * Enables the repeater and allows events to fire.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.ClickRepeater.html#method-enable Original Ext JS documentation of 'enable'
   */
  public native function enable():void;

  /**
   * Convenience function for setting disabled/enabled by boolean.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.ClickRepeater.html#method-setDisabled Original Ext JS documentation of 'setDisabled'
   */
  public native function setDisabled(disabled:Boolean):void;
}
}