package ext.util {
import ext.Base;
import ext.Component;
import ext.dom.Element;
import ext.event.Event;

[Uses("ext.Base")]
[Native("Ext.util.Focusable", require)]
/**
 * @see ext.util.events.Focusable_eventEvent.BLUR
 * @eventType ext.util.events.Focusable_eventEvent.BLUR
 */
[Event(name = 'onBlur', type = 'ext.util.events.Focusable_eventEvent')]
/**
 * @see ext.util.events.Focusable_eventEvent.FOCUS
 * @eventType ext.util.events.Focusable_eventEvent.FOCUS
 */
[Event(name = 'onFocus', type = 'ext.util.events.Focusable_eventEvent')]
/**
 * @see ext.util.events.Focusable_eventEvent.FOCUS_ENTER
 * @eventType ext.util.events.Focusable_eventEvent.FOCUS_ENTER
 */
[Event(name = 'onFocusEnter', type = 'ext.util.events.Focusable_eventEvent')]
/**
 * @see ext.util.events.Focusable_eventEvent.FOCUS_LEAVE
 * @eventType ext.util.events.Focusable_eventEvent.FOCUS_LEAVE
 */
[Event(name = 'onFocusLeave', type = 'ext.util.events.Focusable_eventEvent')]
/**
 * A mixin for individually focusable things (Components, Widgets, etc)
 * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.Focusable.html Original Ext JS documentation of 'Ext.util.Focusable'
 */
public class Focusable extends ext.Base implements ext.util.IFocusable {
  /**
   * @param config @inheritDoc
   */
  public function Focusable(config:ext.util.Focusable = null) {
    super();
  }

  [ExtConfig]
  /**
   * CSS class that will be added to focused
   * Component, and removed when Component blurs.
   * @default 'x-focus'
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.Focusable.html#cfg-focusCls Original Ext JS documentation of 'focusCls'
   */
  public native function get focusCls():String;

  [ExtConfig]
  /**
   * @private
   */
  public native function set focusCls(value:String):void;

  [ExtConfig]
  /**
   * @private
   */
  public native function get focusable():Boolean;

  [ExtConfig]
  /**
   * <code>true</code> for interactive Components, <code>false</code> for static Components.
   * For Containers, this property reflects interactiveness of the
   * Container itself, not its children. See <code>isFocusable()</code>.
   * <p><b>Note:</b> Plain components are static, so not focusable.</p>
   * @default false
   * @see #isFocusable()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.Focusable.html#property-focusable Original Ext JS documentation of 'focusable'
   */
  public native function set focusable(value:Boolean):void;

  [ExtConfig]
  /**
   * DOM tabIndex attribute for this Focusable's
   * focusEl.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.Focusable.html#cfg-tabIndex Original Ext JS documentation of 'tabIndex'
   * @see #getTabIndex()
   * @see #setTabIndex()
   */
  public native function get tabIndex():Number;

  [ExtConfig]
  /**
   * @private
   */
  public native function set tabIndex(value:Number):void;

  /**
   * Template method to do any pre-blur processing.
   * @param e The event object
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.Focusable.html#method-beforeBlur Original Ext JS documentation of 'beforeBlur'
   */
  protected native function beforeBlur(e:ext.event.Event):void;

  /**
   * Template method to do any pre-focus processing.
   * @param e The event object
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.Focusable.html#method-beforeFocus Original Ext JS documentation of 'beforeFocus'
   */
  protected native function beforeFocus(e:ext.event.Event):void;

  /**
   * Cancel any deferred focus on this component
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.Focusable.html#method-cancelFocus Original Ext JS documentation of 'cancelFocus'
   */
  protected native function cancelFocus():void;

  /**
   * Try to focus this component.
   * <p>If this component is disabled, a close relation will be targeted for focus instead
   * to keep focus localized for keyboard users.</p>
   * @param selectText If applicable, <code>true</code> to also select all the text in this component, or an array consisting of start and end (defaults to start) position of selection.
   * @param delay Delay the focus this number of milliseconds (true for 10 milliseconds).
   * @param callback Only needed if the <code>delay</code> parameter is used. A function to call upon focus.
   * @param scope Only needed if the <code>delay</code> parameter is used. The scope (<code>this</code> reference) in which to execute the callback.
   * @return The focused Component. Usually <code>this</code> Component. Some Containers may
   * delegate focus to a descendant Component (<code>ext.window.Window</code>s can do this through their
   * <code>defaultFocus</code> config option. If this component is disabled, a closely
   * related component will be focused and that will be returned.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.Focusable.html#method-focus Original Ext JS documentation of 'focus'
   * @see ext.window.Window
   * @see ext.window.Window#defaultFocus
   */
  public native function focus(selectText:* = undefined, delay:* = undefined, callback:Function = null, scope:Function = null):ext.Component;

  /**
   * Returns the focus styling holder element associated with this Focusable.
   * By default it is the same element as <code>getFocusEl</code>.
   * @return The focus styling element.
   * @see #getFocusEl()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.Focusable.html#method-getFocusClsEl Original Ext JS documentation of 'getFocusClsEl'
   */
  protected native function getFocusClsEl():ext.dom.Element;

  /**
   * Returns the focus holder element associated with this Focusable. At the
   * level of the Focusable base, this function returns <code>this.el</code> (or for Widgets,
   * <code>this.element</code>).
   * <p>Subclasses with embedded focusable elements (such as Window, Field and Button)
   * should override this for use by <code>focus</code>
   * method.</p>
   * @see ext.util.Focusable#focus()
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.Focusable.html#method-getFocusEl Original Ext JS documentation of 'getFocusEl'
   */
  protected native function getFocusEl():ext.dom.Element;

  /**
   * Return the actual tabIndex for this Focusable.
   * @return tabIndex attribute value
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.Focusable.html#method-getTabIndex Original Ext JS documentation of 'getTabIndex'
   */
  public native function getTabIndex():Number;

  /**
   * Template method to do any Focusable related initialization that
   * does not involve event listeners creation.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.Focusable.html#method-initFocusable Original Ext JS documentation of 'initFocusable'
   */
  protected native function initFocusable():void;

  /**
   * Template method to do any event listener initialization for a Focusable.
   * This generally happens after the focusEl is available.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.Focusable.html#method-initFocusableEvents Original Ext JS documentation of 'initFocusableEvents'
   */
  protected native function initFocusableEvents():void;

  /**
   * Determine if this Focusable can receive focus at this time.
   * <p>Note that Containers can be non-focusable themselves while delegating
   * focus treatment to a child Component; see
   * <code>ext.container.Container</code> for more information.</p>
   * @param deep Optionally determine if the container itself
   * is focusable, or if container's focus is delegated to a child component
   * and that child is focusable.
   * @default false
   * @return True if component is focusable, false if not.
   * @see ext.container.Container
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.Focusable.html#method-isFocusable Original Ext JS documentation of 'isFocusable'
   */
  public native function isFocusable(deep:Boolean = false):Boolean;

  /**
   * Called when focus enters this Component's hierarchy
   * @param e
   * @param {ext.event.Event} [e.event] The underlying DOM event.
   * @param {js.HTMLElement} [e.target] The element gaining focus.
   * @param {js.HTMLElement} [e.relatedTarget] The element losing focus.
   * @param {ext.Component} [e.toComponent] The Component gaining focus.
   * @param {ext.Component} [e.fromComponent] The Component losing focus.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.Focusable.html#method-onFocusEnter Original Ext JS documentation of 'onFocusEnter'
   */
  protected native function onFocusEnter(e:Object):void;

  /**
   * Called when focus exits from this Component's hierarchy
   * @param e
   * @param {ext.event.Event} [e.event] The underlying DOM event.
   * @param {js.HTMLElement} [e.target] The element gaining focus.
   * @param {js.HTMLElement} [e.relatedTarget] The element losing focus.
   * @param {ext.Component} [e.toComponent] The Component gaining focus.
   * @param {ext.Component} [e.fromComponent] The Component losing focus.
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.Focusable.html#method-onFocusLeave Original Ext JS documentation of 'onFocusLeave'
   */
  protected native function onFocusLeave(e:ext.event.Event):void;

  /**
   * Template method to do any post-blur processing.
   * @param e The event object
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.Focusable.html#method-postBlur Original Ext JS documentation of 'postBlur'
   */
  protected native function postBlur(e:ext.event.Event):void;

  /**
   * Template method to do any post-focus processing.
   * @param e The event object
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.Focusable.html#method-postFocus Original Ext JS documentation of 'postFocus'
   */
  protected native function postFocus(e:ext.event.Event):void;

  /**
   * Set the tabIndex property for this Focusable. If the focusEl
   * is available, set tabIndex attribute on it, too.
   * @param newTabIndex new tabIndex to set
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.util.Focusable.html#method-setTabIndex Original Ext JS documentation of 'setTabIndex'
   */
  public native function setTabIndex(newTabIndex:Number):void;
}
}