package ext.view {
import ext.Component;
import ext.mixin.IQueryable;
import ext.toolbar.PagingToolbar;

[Uses("ext.view.DataView")]
[Uses("ext.mixin.Queryable")]
[Uses("ext.view.AbstractView")]
[Uses("ext.Component")]
[Uses("ext.util.Animate")]
[Uses("ext.Base")]
[Uses("ext.util.ElementContainer")]
[Uses("ext.util.Focusable")]
[Uses("ext.mixin.ComponentDelegation")]
[Uses("ext.Mixin")]
[Uses("ext.mixin.Inheritable")]
[Uses("ext.util.Positionable")]
[Uses("ext.mixin.Bindable")]
[Uses("ext.mixin.Keyboard")]
[Uses("ext.mixin.Observable")]
[Uses("ext.mixin.Identifiable")]
[Uses("ext.state.Stateful")]
[Uses("ext.mixin.Accessible")]
[Uses("ext.util.Renderable")]
[Uses("ext.util.Floating")]
[Uses("ext.util.StoreHolder")]
[Native("Ext.view.BoundList", require)]
/**
 * An internally used DataView for <code>ext.form.field.ComboBox</code>.
 * @see ext.form.field.ComboBox
 * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.view.BoundList.html Original Ext JS documentation of 'Ext.view.BoundList'
 */
public class BoundListView extends ext.view.DataView implements ext.mixin.IQueryable {
  /**
   * @param config @inheritDoc
   */
  public function BoundListView(config:ext.view.BoundListView = null) {
    super();
  }

  [ExtConfig]
  /**
   * The field from the store to show in the view.
   * @default ""
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.view.BoundList.html#cfg-displayField Original Ext JS documentation of 'displayField'
   * @see #setDisplayField()
   */
  public native function get displayField():String;

  [ExtConfig]
  [Bindable(event = "DUMMY")]
  /**
   * @private
   */
  public native function set displayField(value:String):void;

  [ExtConfig]
  /**
   * If greater than <code>0</code>, a <code>ext.toolbar.PagingToolbar</code> is displayed at the bottom of the list and store
   * queries will execute with page <code>start</code> and
   * <code>limit</code> parameters.
   * @default 0
   * @see ext.toolbar.PagingToolbar
   * @see ext.data.operation.ReadOperation#start
   * @see ext.data.operation.ReadOperation#limit
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.view.BoundList.html#cfg-pageSize Original Ext JS documentation of 'pageSize'
   */
  public native function get pageSize():Number;

  [ExtConfig]
  /**
   * @private
   */
  public native function set pageSize(value:Number):void;

  /**
   * A reference to the PagingToolbar instance in this view. Only populated if <code>pageSize</code> is greater
   * than zero and the BoundList has been rendered.
   * @see #pageSize
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.view.BoundList.html#property-pagingToolbar Original Ext JS documentation of 'pagingToolbar'
   */
  public native function get pagingToolbar():ext.toolbar.PagingToolbar;

  /**
   * @private
   */
  public native function set pagingToolbar(value:ext.toolbar.PagingToolbar):void;

  [ExtConfig]
  /**
   * A String or Ext.XTemplate instance to apply to inner template.
   * <p><code>ext.view.BoundListView</code> is used for the dropdown list of
   * <code>ext.form.field.ComboBox</code>. To customize the template you can set the tpl on
   * the combobox config object:</p>
   * <pre>
   * Ext.create('Ext.form.field.ComboBox', {
   *     fieldLabel   : 'State',
   *     queryMode    : 'local',
   *     displayField : 'text',
   *     valueField   : 'abbr',
   *     store        : Ext.create('StateStore', {
   *         fields : ['abbr', 'text'],
   *         data   : [
   *             {"abbr":"AL", "name":"Alabama"},
   *             {"abbr":"AK", "name":"Alaska"},
   *             {"abbr":"AZ", "name":"Arizona"}
   *             //...
   *         ]
   *     }),
   *     // Template for the dropdown menu.
   *     // Note the use of the "x-list-plain" and "x-boundlist-item" class,
   *     // this is required to make the items selectable.
   *     tpl: Ext.create('Ext.XTemplate',
   *         '&lt;ul class="x-list-plain"&gt;&lt;tpl for="."&gt;',
   *             '&lt;li role="option" class="x-boundlist-item"&gt;{abbr} - {name}&lt;/li&gt;',
   *         '&lt;/tpl&gt;&lt;/ul&gt;'
   *     ),
   * });
   * </pre>
   * <p>Defaults to:</p>
   * <pre>
   * Ext.create('Ext.XTemplate',
   *     '&lt;ul&gt;&lt;tpl for="."&gt;',
   *         '&lt;li role="option" class="' + itemCls + '"&gt;' + me.getInnerTpl(me.displayField) + '&lt;/li&gt;',
   *     '&lt;/tpl&gt;&lt;/ul&gt;'
   * );
   * </pre>
   * @see ext.view.BoundListView
   * @see ext.form.field.ComboBox
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.view.BoundList.html#cfg-tpl Original Ext JS documentation of 'tpl'
   */
  override public native function get tpl():*;

  [ExtConfig]
  /**
   * @private
   */
  override public native function set tpl(value:*):void;

  /**
   * @inheritDoc
   */
  public native function child(selector:* = undefined):ext.Component;

  /**
   * @inheritDoc
   */
  public native function down(selector:* = undefined):ext.Component;

  /**
   * A method that returns the inner template for displaying items in the list.
   * This method is useful to override when using a more complex display value, for example
   * inserting an icon along with the text.
   * <p>The XTemplate is created with a reference to the owning form field in the <code>field</code> property to provide access
   * to context. For example to highlight the currently typed value, the getInnerTpl may be configured into a
   * ComboBox as part of the <code>listConfig</code>:</p>
   * <pre>
   * listConfig: {
   *     getInnerTpl: function() {
   *         return '{[values.name.replace(this.field.getRawValue(), "&lt;b&gt;" + this.field.getRawValue() + "&lt;/b&gt;")]}';
   *     }
   * }
   * </pre>
   * @param displayField The <code>displayField</code> for the BoundList.
   * @return The inner template
   * @see ext.form.field.ComboBox#listConfig
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.view.BoundList.html#method-getInnerTpl Original Ext JS documentation of 'getInnerTpl'
   * @see #displayField
   */
  public native function getInnerTpl(displayField:String):String;

  /**
   * @inheritDoc
   */
  public native function query(selector:String = null):Array;

  /**
   * @inheritDoc
   */
  public native function queryBy(fn:Function, scope:Object = null):Array;

  /**
   * @inheritDoc
   */
  public native function queryById(id:String):ext.Component;

  /**
   * Updates the display field for this view. This will automatically trigger
   * an regeneration of the tpl so that the updated displayField can be used
   * @see https://docs.sencha.com/extjs/6.2.1/classic/Ext.view.BoundList.html#method-setDisplayField Original Ext JS documentation of 'setDisplayField'
   */
  public native function setDisplayField(displayField:String):void;

  /**
   * @inheritDoc
   */
  public native function visitPostOrder(selector:Object, fn:Function, scope:Object = null, extraArgs:Array = null):void;

  /**
   * @inheritDoc
   */
  public native function visitPreOrder(selector:Object, fn:Function, scope:Object = null, extraArgs:Array = null):void;
}
}